"""
"""

import json

from thrift import TSerialization
from thrift.protocol import TJSONProtocol

from concrete.util import read_communication_from_file


def communication_file_to_json(communication_filename):
    """
    Takes a Communication filename, deserializes Communication from
    file, returns a JSON string with the information in that
    Communication.
    """
    comm = read_communication_from_file(communication_filename)
    return communication_to_json(comm)


def communication_to_json(comm):
    """
    Takes a Communication instance, returns a JSON string with the
    information in that Communication.
    """
    comm_json_string = TSerialization.serialize(comm, TJSONProtocol.TSimpleJSONProtocolFactory())
    comm_json = json.loads(comm_json_string)
    return json.dumps(comm_json, indent=2, separators=(',', ': '), ensure_ascii=False, sort_keys=True)



#!/usr/bin/env python
"""
Pretty-prints a Concrete Communication file as JSON
"""

import argparse
import codecs
import sys

from concrete.util import communication_file_to_json


def main():
    # Make stdout output UTF-8, preventing "'ascii' codec can't encode" errors
    sys.stdout = codecs.getwriter('utf8')(sys.stdout)

    parser = argparse.ArgumentParser(description="Pretty Print a Concrete Communication file")
    parser.add_argument('communication_file')
    parser.add_argument('json_file', nargs='?', default='STDOUT')
    args = parser.parse_args()

    if args.json_file == 'STDOUT':
        print communication_file_to_json(args.communication_file)
    else:
        f = codecs.open(args.json_file, "w", encoding="utf-8")
        f.write(communication_file_to_json(args.communication_file))
        f.close()


if __name__ == "__main__":
    main()



#
# Autogenerated by Thrift Compiler (1.0.0-dev)
#
# DO NOT EDIT UNLESS YOU ARE SURE THAT YOU KNOW WHAT YOU ARE DOING
#
#  options string: py:new_style,utf8strings
#

from thrift.Thrift import TType, TMessageType, TException, TApplicationException

from thrift.transport import TTransport
from thrift.protocol import TBinaryProtocol, TProtocol
try:
  from thrift.protocol import fastbinary
except:
  fastbinary = None



class Digest(object):
  """
  Analytic-specific information about an attribute or edge. Digests
  are used to combine information from multiple sources to generate a
  unified value. The digests generated by an analytic will only ever
  be used by that same analytic, so analytics can feel free to encode
  information in whatever way is convenient.

  Attributes:
   - bytesValue: The following fields define various ways you can store the
  digest data (for convenience). If none of these meets your
  needs, then serialize the digest to a byte sequence and store it
  in bytesValue.
   - int64Value
   - doubleValue
   - stringValue
   - int64List
   - doubleList
   - stringList
  """

  thrift_spec = (
    None, # 0
    (1, TType.STRING, 'bytesValue', None, None, ), # 1
    (2, TType.I64, 'int64Value', None, None, ), # 2
    (3, TType.DOUBLE, 'doubleValue', None, None, ), # 3
    (4, TType.STRING, 'stringValue', None, None, ), # 4
    (5, TType.LIST, 'int64List', (TType.I64,None), None, ), # 5
    (6, TType.LIST, 'doubleList', (TType.DOUBLE,None), None, ), # 6
    (7, TType.LIST, 'stringList', (TType.STRING,None), None, ), # 7
  )

  def __init__(self, bytesValue=None, int64Value=None, doubleValue=None, stringValue=None, int64List=None, doubleList=None, stringList=None,):
    self.bytesValue = bytesValue
    self.int64Value = int64Value
    self.doubleValue = doubleValue
    self.stringValue = stringValue
    self.int64List = int64List
    self.doubleList = doubleList
    self.stringList = stringList

  def read(self, iprot):
    if iprot.__class__ == TBinaryProtocol.TBinaryProtocolAccelerated and isinstance(iprot.trans, TTransport.CReadableTransport) and self.thrift_spec is not None and fastbinary is not None:
      fastbinary.decode_binary(self, iprot.trans, (self.__class__, self.thrift_spec))
      return
    iprot.readStructBegin()
    while True:
      (fname, ftype, fid) = iprot.readFieldBegin()
      if ftype == TType.STOP:
        break
      if fid == 1:
        if ftype == TType.STRING:
          self.bytesValue = iprot.readString();
        else:
          iprot.skip(ftype)
      elif fid == 2:
        if ftype == TType.I64:
          self.int64Value = iprot.readI64();
        else:
          iprot.skip(ftype)
      elif fid == 3:
        if ftype == TType.DOUBLE:
          self.doubleValue = iprot.readDouble();
        else:
          iprot.skip(ftype)
      elif fid == 4:
        if ftype == TType.STRING:
          self.stringValue = iprot.readString().decode('utf-8')
        else:
          iprot.skip(ftype)
      elif fid == 5:
        if ftype == TType.LIST:
          self.int64List = []
          (_etype3, _size0) = iprot.readListBegin()
          for _i4 in xrange(_size0):
            _elem5 = iprot.readI64();
            self.int64List.append(_elem5)
          iprot.readListEnd()
        else:
          iprot.skip(ftype)
      elif fid == 6:
        if ftype == TType.LIST:
          self.doubleList = []
          (_etype9, _size6) = iprot.readListBegin()
          for _i10 in xrange(_size6):
            _elem11 = iprot.readDouble();
            self.doubleList.append(_elem11)
          iprot.readListEnd()
        else:
          iprot.skip(ftype)
      elif fid == 7:
        if ftype == TType.LIST:
          self.stringList = []
          (_etype15, _size12) = iprot.readListBegin()
          for _i16 in xrange(_size12):
            _elem17 = iprot.readString().decode('utf-8')
            self.stringList.append(_elem17)
          iprot.readListEnd()
        else:
          iprot.skip(ftype)
      else:
        iprot.skip(ftype)
      iprot.readFieldEnd()
    iprot.readStructEnd()

  def write(self, oprot):
    if oprot.__class__ == TBinaryProtocol.TBinaryProtocolAccelerated and self.thrift_spec is not None and fastbinary is not None:
      oprot.trans.write(fastbinary.encode_binary(self, (self.__class__, self.thrift_spec)))
      return
    oprot.writeStructBegin('Digest')
    if self.bytesValue is not None:
      oprot.writeFieldBegin('bytesValue', TType.STRING, 1)
      oprot.writeString(self.bytesValue)
      oprot.writeFieldEnd()
    if self.int64Value is not None:
      oprot.writeFieldBegin('int64Value', TType.I64, 2)
      oprot.writeI64(self.int64Value)
      oprot.writeFieldEnd()
    if self.doubleValue is not None:
      oprot.writeFieldBegin('doubleValue', TType.DOUBLE, 3)
      oprot.writeDouble(self.doubleValue)
      oprot.writeFieldEnd()
    if self.stringValue is not None:
      oprot.writeFieldBegin('stringValue', TType.STRING, 4)
      oprot.writeString(self.stringValue.encode('utf-8'))
      oprot.writeFieldEnd()
    if self.int64List is not None:
      oprot.writeFieldBegin('int64List', TType.LIST, 5)
      oprot.writeListBegin(TType.I64, len(self.int64List))
      for iter18 in self.int64List:
        oprot.writeI64(iter18)
      oprot.writeListEnd()
      oprot.writeFieldEnd()
    if self.doubleList is not None:
      oprot.writeFieldBegin('doubleList', TType.LIST, 6)
      oprot.writeListBegin(TType.DOUBLE, len(self.doubleList))
      for iter19 in self.doubleList:
        oprot.writeDouble(iter19)
      oprot.writeListEnd()
      oprot.writeFieldEnd()
    if self.stringList is not None:
      oprot.writeFieldBegin('stringList', TType.LIST, 7)
      oprot.writeListBegin(TType.STRING, len(self.stringList))
      for iter20 in self.stringList:
        oprot.writeString(iter20.encode('utf-8'))
      oprot.writeListEnd()
      oprot.writeFieldEnd()
    oprot.writeFieldStop()
    oprot.writeStructEnd()

  def validate(self):
    return


  def __repr__(self):
    L = ['%s=%r' % (key, value)
      for key, value in self.__dict__.iteritems()]
    return '%s(%s)' % (self.__class__.__name__, ', '.join(L))

  def __eq__(self, other):
    return isinstance(other, self.__class__) and self.__dict__ == other.__dict__

  def __ne__(self, other):
    return not (self == other)

class AnnotationMetadata(object):
  """
  Metadata associated with an annotation or a set of annotations,
  that identifies where those annotations came from.

  Attributes:
   - tool: The name of the tool that generated this annotation.
   - timestamp: The time at which this annotation was generated (in unix time
  UTC -- i.e., seconds since January 1, 1970).
   - confidence: Confidence score. To do: define what this means!
   - digest: A Digest, carrying over any information the annotation metadata
  wishes to carry over.
  """

  thrift_spec = (
    None, # 0
    (1, TType.STRING, 'tool', None, None, ), # 1
    (2, TType.I64, 'timestamp', None, None, ), # 2
    (3, TType.DOUBLE, 'confidence', None, None, ), # 3
    (4, TType.STRUCT, 'digest', (Digest, Digest.thrift_spec), None, ), # 4
  )

  def __init__(self, tool=None, timestamp=None, confidence=None, digest=None,):
    self.tool = tool
    self.timestamp = timestamp
    self.confidence = confidence
    self.digest = digest

  def read(self, iprot):
    if iprot.__class__ == TBinaryProtocol.TBinaryProtocolAccelerated and isinstance(iprot.trans, TTransport.CReadableTransport) and self.thrift_spec is not None and fastbinary is not None:
      fastbinary.decode_binary(self, iprot.trans, (self.__class__, self.thrift_spec))
      return
    iprot.readStructBegin()
    while True:
      (fname, ftype, fid) = iprot.readFieldBegin()
      if ftype == TType.STOP:
        break
      if fid == 1:
        if ftype == TType.STRING:
          self.tool = iprot.readString().decode('utf-8')
        else:
          iprot.skip(ftype)
      elif fid == 2:
        if ftype == TType.I64:
          self.timestamp = iprot.readI64();
        else:
          iprot.skip(ftype)
      elif fid == 3:
        if ftype == TType.DOUBLE:
          self.confidence = iprot.readDouble();
        else:
          iprot.skip(ftype)
      elif fid == 4:
        if ftype == TType.STRUCT:
          self.digest = Digest()
          self.digest.read(iprot)
        else:
          iprot.skip(ftype)
      else:
        iprot.skip(ftype)
      iprot.readFieldEnd()
    iprot.readStructEnd()

  def write(self, oprot):
    if oprot.__class__ == TBinaryProtocol.TBinaryProtocolAccelerated and self.thrift_spec is not None and fastbinary is not None:
      oprot.trans.write(fastbinary.encode_binary(self, (self.__class__, self.thrift_spec)))
      return
    oprot.writeStructBegin('AnnotationMetadata')
    if self.tool is not None:
      oprot.writeFieldBegin('tool', TType.STRING, 1)
      oprot.writeString(self.tool.encode('utf-8'))
      oprot.writeFieldEnd()
    if self.timestamp is not None:
      oprot.writeFieldBegin('timestamp', TType.I64, 2)
      oprot.writeI64(self.timestamp)
      oprot.writeFieldEnd()
    if self.confidence is not None:
      oprot.writeFieldBegin('confidence', TType.DOUBLE, 3)
      oprot.writeDouble(self.confidence)
      oprot.writeFieldEnd()
    if self.digest is not None:
      oprot.writeFieldBegin('digest', TType.STRUCT, 4)
      self.digest.write(oprot)
      oprot.writeFieldEnd()
    oprot.writeFieldStop()
    oprot.writeStructEnd()

  def validate(self):
    if self.tool is None:
      raise TProtocol.TProtocolException(message='Required field tool is unset!')
    return


  def __repr__(self):
    L = ['%s=%r' % (key, value)
      for key, value in self.__dict__.iteritems()]
    return '%s(%s)' % (self.__class__.__name__, ', '.join(L))

  def __eq__(self, other):
    return isinstance(other, self.__class__) and self.__dict__ == other.__dict__

  def __ne__(self, other):
    return not (self == other)



# -*- coding: utf-8 -*-

# The 'coding' line above was manually added to the autogenerated code
# to prevent the error message on import:
#   SyntaxError: Non-ASCII character '\xef' in file concrete/nitf/ttypes.py

#
# Autogenerated by Thrift Compiler (1.0.0-dev)
#
# DO NOT EDIT UNLESS YOU ARE SURE THAT YOU KNOW WHAT YOU ARE DOING
#
#  options string: py:new_style,utf8strings
#

from thrift.Thrift import TType, TMessageType, TException, TApplicationException

from thrift.transport import TTransport
from thrift.protocol import TBinaryProtocol, TProtocol
try:
  from thrift.protocol import fastbinary
except:
  fastbinary = None



class NITFInfo(object):
  """
  Attributes:
   - alternateURL: This field specifies the location on nytimes.com of the article. When
  present, this URL is preferred to the URL field on articles published on
  or after April 02, 2006, as the linked page will have richer content.
   - articleAbstract: This field is a summary of the article written by the New York Times
  Indexing Service.
   - authorBiography: This field specifies the biography of the author of the article.
  Generally, this field is specified for guest authors not for New York
  Times reporters. When this field is specified for Times reporters, it is
  usually used to provide the author's email address.
   - banner: The banner field is used to indicate if there has been additional
  information appended to the articles since its publication. Examples of
  banners include ('Correction Appended' and 'Editor's Note Appended').
   - biographicalCategories: When present, the biographical category field generally indicates that a
  document focuses on a particular individual. The value of the field
  indicates the area or category in which this individual is best known.
  This field is most often defined for Obituaries and Book Reviews. These
  tags are hand-assigned by a team of library scientists working for the
  New York Times Indexing service.

  <ol>
  <li>Politics and Government (U.S.) <li>Books and Magazines <li>Royalty
  </ol>
   - body: The body field is the text content of the article. Please note that this
  value includes the lead paragraph.
   - byline: This field specifies the byline of the article as it appeared in the
  print edition of the New York Times. Please note that not every article
  in this collection has a byline, as editorials and other types of
  articles are generally unsigned.
  <P>
  Sample byline:
  <ul>
  <li>By James Reston
  <li>By JAMES GLANZ; William J. Broad contributed reporting for this
  article.
  <li>By ADAM NAGOURNEY and JEFF ZELENY
  </ul>
   - columnName: If the article is part of a regular column, this field specifies the name
  of that column.
  <p>
  Sample Column Names:
  <p>
  <ol>
  <li>World News Briefs
  <li>WEDDINGS
  <li>The Accessories Channel
  </ol>

   - columnNumber: This field specifies the column in which the article starts in the print
  paper. A typical printed page in the paper has six columns numbered from
  right to left. As a consequence most, but not all, of the values for this
  field fall in the range 1-6.
   - correctionDate: This field specifies the date on which a correction was made to the
  article. Generally, if the correction date is specified, the correction
  text will also be specified (and vice versa).
   - correctionText: For articles corrected following publication, this field specifies the
  correction. Generally, if the correction text is specified, the
  correction date will also be specified (and vice versa).
   - credit: This field indicates the entity that produced the editorial content of
  this document. For this collection, the credit will always be set to 'The
  New York Times'.
   - dateline: The �dateline� field is the dateline of the article. Generally a dateline
  is the name of the geographic location from which the article was filed
  followed by a comma and the month and day of the filing.
  <p>
  Sample datelines:
  <ul>
  <li>WASHINGTON, April 30
  <li>RIYADH, Saudi Arabia, March 29
  <li>ONTARIO, N.Y., Jan. 26
  </ul>
  Please note:
  <ol>
  <li>The dateline location is the location from which the article was
  filed. Often times this location is related to the content of the
  article, but this is not guaranteed.
  <li>The date specified for the dateline is often but not always the day
  previous to the publication date.
  <li>The date is usually but not always specified.
  </ol>
   - dayOfWeek: This field specifies the day of week on which the article was published.
  <ul>
  <li>Monday <li>Tuesday <li>Wednesday <li>Thursday <li>Friday <li>Saturday
  <li>Sunday
  </ul>
   - descriptors: The �descriptors� field specifies a list of descriptive terms drawn from
  a normalized controlled vocabulary corresponding to subjects mentioned in
  the article. These tags are hand-assigned by a team of library scientists
  working in the New York Times Indexing service.
  <p>
  Examples Include:
  <ol>
  <li>ECONOMIC CONDITIONS AND TRENDS
  <li>AIRPLANES
  <li>VIOLINS
  </ol>
   - featurePage: The
   - generalOnlineDescriptors: The �general online descriptors� field specifies a list of descriptors
  that are at a higher level of generality than the other tags associated
  with the article. These tags are algorithmically assigned and manually
  verified by nytimes.com production staff.
  <p>
  Examples Include:
  <ol>
  <li>Surfing
  <li>Venice Biennale
  <li>Ranches
  </ol>
   - guid: The GUID field specifies a an integer that is guaranteed to be unique for
  every document in the corpus.
   - headline: This field specifies the headline of the article as it appeared in the
  print edition of the New York Times.
   - kicker: The kicker is an additional piece of information printed as an
  accompaniment to a news headline.
   - leadParagraph: The �lead Paragraph� field is the lead paragraph of the article.
  Generally this field is populated with the first two paragraphs from the
  article.
   - locations: The �locations� field specifies a list of geographic descriptors drawn
  from a normalized controlled vocabulary that correspond to places
  mentioned in the article. These tags are hand-assigned by a team of
  library scientists working for the New York Times Indexing service.
  <p>
  Examples Include:
  <ol>
  <li>Wellsboro (Pa)
  <li>Kansas City (Kan)
  <li>Park Slope (NYC)
  </ol>
   - names: The �names� field specifies a list of names mentioned in the article.
  These tags are hand-assigned by a team of library scientists working for
  the New York Times Indexing service.
  <p>
  Examples Include:
  <ol>
  <li>Azza Fahmy
  <li>George C. Izenour
  <li>Chris Schenkel
  </ol>
   - newsDesk: This field specifies the desk in the New York Times newsroom that
  produced the article. The desk is related to, but is not the same as the
  section in which the article appears.
   - normalizedByline: The Normalized Byline field is the byline normalized to the form (last
  name, first name).
   - onlineDescriptors: This field specifies a list of descriptors from a normalized controlled
  vocabulary that correspond to topics mentioned in the article. These tags
  are algorithmically assigned and manually verified by nytimes.com
  production staff.
  <p>
  Examples Include:
  <ol>
  <li>Marriages
  <li>Parks and Other Recreation Areas
  <li>Cooking and Cookbooks
  </ol>
   - onlineHeadline: This field specifies the headline displayed with the article on
  nytimes.com. Often this differs from the headline used in print.
   - onlineLeadParagraph: This field specifies the lead paragraph as defined by the producers at
  nytimes.com.
   - onlineLocations: This field specifies a list of place names that correspond to geographic
  locations mentioned in the article. These tags are algorithmically
  assigned and manually verified by nytimes.com production staff.
  <p>
  Examples Include:
  <ol>
  <li>Hollywood
  <li>Los Angeles
  <li>Arcadia
  </ol>
   - onlineOrganizations: This field specifies a list of organizations that correspond to
  organizations mentioned in the article. These tags are algorithmically
  assigned and manually verified by nytimes.com production staff.
  <p>
  Examples Include:
  <ol>
  <li>Nintendo Company Limited
  <li>Yeshiva University
  <li>Rose Center
  </ol>
   - onlinePeople: This field specifies a list of people that correspond to individuals
  mentioned in the article. These tags are algorithmically assigned and
  manually verified by nytimes.com production staff.
  <p>
  Examples Include:
  <ol>
  <li>Lopez, Jennifer
  <li>Joyce, James
  <li>Robinson, Jackie
  </ol>
   - onlineSection: This field specifies the section(s) on nytimes.com in which the article
  is placed. If the article is placed in multiple sections, this field will
  be specified as a �;� delineated list.
   - onlineTitles: This field specifies a list of authored works mentioned in the article.
  These tags are algorithmically assigned and manually verified by
  nytimes.com production staff.
  <p>
  Examples Include:
  <ol>
  <li>Matchstick Men (Movie)
  <li>Blades of Glory (Movie)
  <li>Bridge & Tunnel (Play)
  </ol>
   - organizations: This field specifies a list of organization names drawn from a normalized
  controlled vocabulary that correspond to organizations mentioned in the
  article. These tags are hand-assigned by a team of library scientists
  working in the New York Times Indexing service.
  <p>
  Examples Include:
  <ol>
  <li>Circuit City Stores Inc
  <li>Delaware County Community College (Pa)
  <li>CONNECTICUT GRAND OPERA
  </ol>
   - page: This field specifies the page of the section in the paper in which the
  article appears. This is not an absolute pagination. An article that
  appears on page 3 in section A occurs in the physical paper before an
  article that occurs on page 1 of section F.
   - people: This field specifies a list of people from a normalized controlled
  vocabulary that correspond to individuals mentioned in the article. These
  tags are hand-assigned by a team of library scientists working in the New
  York Times Indexing service.
  <p>
  Examples Include:
  <ol>
  <li>REAGAN, RONALD WILSON (PRES)
  <li>BEGIN, MENACHEM (PRIME MIN)
  <li>COLLINS, GLENN
  </ol>
   - publicationDate: This field specifies the date of the article�s publication.
   - publicationDayOfMonth: This field specifies the day of the month on which the article was
  published, always in the range 1-31.
   - publicationMonth: This field specifies the month on which the article was published in the
  range 1-12 where 1 is January 2 is February etc.
   - publicationYear: This field specifies the year in which the article was published. This
  value is in the range 1987-2007 for this collection.
   - section: This field specifies the section of the paper in which the article
  appears. This is not the name of the section, but rather a letter or
  number that indicates the section.
   - seriesName: If the article is part of a regular series, this field specifies the name
  of that column.
   - slug: The slug is a short string that uniquely identifies an article from all
  other articles published on the same day. Please note, however, that
  different articles on different days may have the same slug.
  <ul>
  <li>30other <li>12reunion
  </ul>
   - sourceFilePath: The file from which this object was read.
   - taxonomicClassifiers: This field specifies a list of taxonomic classifiers that place this
  article into a hierarchy of articles. The individual terms of each
  taxonomic classifier are separated with the '/' character. These tags are
  algorithmically assigned and manually verified by nytimes.com production
  staff. These tags are algorithmically assigned and manually verified by
  nytimes.com production staff.
  <p>
  Examples Include:
  <ol>
  <li>Top/Features/Travel/Guides/Destinations/North America/United
  States/Arizona
  <li>Top/News/U.S./Rockies
  <li>Top/Opinion
  </ol>
   - titles: This field specifies a list of authored works that correspond to works
  mentioned in the article. These tags are hand-assigned by a team of
  library scientists working in the New York Times Indexing service.
  <p>
  Examples Include:
  <ol>
  <li>Greystoke: The Legend of Tarzan, Lord of the Apes (Movie)
  <li>Law & Order (TV Program)
  <li>BATTLEFIELD EARTH (BOOK)
  </ol>
   - typesOfMaterial: This field specifies a normalized list of terms describing the general
  editorial category of the article. These tags are algorithmically
  assigned and manually verified by nytimes.com production staff.
  <p>
  Examples Include:
  <ol>
  <li>REVIEW
  <li>OBITUARY
  <li>ANALYSIS
  </ol>
   - url: This field specifies the location on nytimes.com of the article. The
  �Alternative Url� field is preferred to this field on articles published
  on or after April 02, 2006, as the linked page will have richer content.
   - wordCount: This field specifies the number of words in the body of the article,
  including the lead paragraph.
  """

  thrift_spec = (
    None, # 0
    (1, TType.STRING, 'alternateURL', None, None, ), # 1
    (2, TType.STRING, 'articleAbstract', None, None, ), # 2
    (3, TType.STRING, 'authorBiography', None, None, ), # 3
    (4, TType.STRING, 'banner', None, None, ), # 4
    (5, TType.LIST, 'biographicalCategories', (TType.STRING,None), None, ), # 5
    (6, TType.STRING, 'body', None, None, ), # 6
    (7, TType.STRING, 'byline', None, None, ), # 7
    (8, TType.STRING, 'columnName', None, None, ), # 8
    (9, TType.I32, 'columnNumber', None, None, ), # 9
    (10, TType.I64, 'correctionDate', None, None, ), # 10
    (11, TType.STRING, 'correctionText', None, None, ), # 11
    (12, TType.STRING, 'credit', None, None, ), # 12
    (13, TType.STRING, 'dateline', None, None, ), # 13
    (14, TType.STRING, 'dayOfWeek', None, None, ), # 14
    (15, TType.LIST, 'descriptors', (TType.STRING,None), None, ), # 15
    (16, TType.STRING, 'featurePage', None, None, ), # 16
    (17, TType.LIST, 'generalOnlineDescriptors', (TType.STRING,None), None, ), # 17
    (18, TType.I32, 'guid', None, None, ), # 18
    (19, TType.STRING, 'headline', None, None, ), # 19
    (20, TType.STRING, 'kicker', None, None, ), # 20
    (21, TType.STRING, 'leadParagraph', None, None, ), # 21
    (22, TType.LIST, 'locations', (TType.STRING,None), None, ), # 22
    (23, TType.LIST, 'names', (TType.STRING,None), None, ), # 23
    (24, TType.STRING, 'newsDesk', None, None, ), # 24
    (25, TType.STRING, 'normalizedByline', None, None, ), # 25
    (26, TType.LIST, 'onlineDescriptors', (TType.STRING,None), None, ), # 26
    (27, TType.STRING, 'onlineHeadline', None, None, ), # 27
    (28, TType.STRING, 'onlineLeadParagraph', None, None, ), # 28
    (29, TType.LIST, 'onlineLocations', (TType.STRING,None), None, ), # 29
    (30, TType.LIST, 'onlineOrganizations', (TType.STRING,None), None, ), # 30
    (31, TType.LIST, 'onlinePeople', (TType.STRING,None), None, ), # 31
    (32, TType.STRING, 'onlineSection', None, None, ), # 32
    (33, TType.LIST, 'onlineTitles', (TType.STRING,None), None, ), # 33
    (34, TType.LIST, 'organizations', (TType.STRING,None), None, ), # 34
    (35, TType.I32, 'page', None, None, ), # 35
    (36, TType.LIST, 'people', (TType.STRING,None), None, ), # 36
    (37, TType.I64, 'publicationDate', None, None, ), # 37
    (38, TType.I32, 'publicationDayOfMonth', None, None, ), # 38
    (39, TType.I32, 'publicationMonth', None, None, ), # 39
    (40, TType.I32, 'publicationYear', None, None, ), # 40
    (41, TType.STRING, 'section', None, None, ), # 41
    (42, TType.STRING, 'seriesName', None, None, ), # 42
    (43, TType.STRING, 'slug', None, None, ), # 43
    (44, TType.STRING, 'sourceFilePath', None, None, ), # 44
    (45, TType.LIST, 'taxonomicClassifiers', (TType.STRING,None), None, ), # 45
    (46, TType.LIST, 'titles', (TType.STRING,None), None, ), # 46
    (47, TType.LIST, 'typesOfMaterial', (TType.STRING,None), None, ), # 47
    (48, TType.STRING, 'url', None, None, ), # 48
    (49, TType.I32, 'wordCount', None, None, ), # 49
  )

  def __init__(self, alternateURL=None, articleAbstract=None, authorBiography=None, banner=None, biographicalCategories=None, body=None, byline=None, columnName=None, columnNumber=None, correctionDate=None, correctionText=None, credit=None, dateline=None, dayOfWeek=None, descriptors=None, featurePage=None, generalOnlineDescriptors=None, guid=None, headline=None, kicker=None, leadParagraph=None, locations=None, names=None, newsDesk=None, normalizedByline=None, onlineDescriptors=None, onlineHeadline=None, onlineLeadParagraph=None, onlineLocations=None, onlineOrganizations=None, onlinePeople=None, onlineSection=None, onlineTitles=None, organizations=None, page=None, people=None, publicationDate=None, publicationDayOfMonth=None, publicationMonth=None, publicationYear=None, section=None, seriesName=None, slug=None, sourceFilePath=None, taxonomicClassifiers=None, titles=None, typesOfMaterial=None, url=None, wordCount=None,):
    self.alternateURL = alternateURL
    self.articleAbstract = articleAbstract
    self.authorBiography = authorBiography
    self.banner = banner
    self.biographicalCategories = biographicalCategories
    self.body = body
    self.byline = byline
    self.columnName = columnName
    self.columnNumber = columnNumber
    self.correctionDate = correctionDate
    self.correctionText = correctionText
    self.credit = credit
    self.dateline = dateline
    self.dayOfWeek = dayOfWeek
    self.descriptors = descriptors
    self.featurePage = featurePage
    self.generalOnlineDescriptors = generalOnlineDescriptors
    self.guid = guid
    self.headline = headline
    self.kicker = kicker
    self.leadParagraph = leadParagraph
    self.locations = locations
    self.names = names
    self.newsDesk = newsDesk
    self.normalizedByline = normalizedByline
    self.onlineDescriptors = onlineDescriptors
    self.onlineHeadline = onlineHeadline
    self.onlineLeadParagraph = onlineLeadParagraph
    self.onlineLocations = onlineLocations
    self.onlineOrganizations = onlineOrganizations
    self.onlinePeople = onlinePeople
    self.onlineSection = onlineSection
    self.onlineTitles = onlineTitles
    self.organizations = organizations
    self.page = page
    self.people = people
    self.publicationDate = publicationDate
    self.publicationDayOfMonth = publicationDayOfMonth
    self.publicationMonth = publicationMonth
    self.publicationYear = publicationYear
    self.section = section
    self.seriesName = seriesName
    self.slug = slug
    self.sourceFilePath = sourceFilePath
    self.taxonomicClassifiers = taxonomicClassifiers
    self.titles = titles
    self.typesOfMaterial = typesOfMaterial
    self.url = url
    self.wordCount = wordCount

  def read(self, iprot):
    if iprot.__class__ == TBinaryProtocol.TBinaryProtocolAccelerated and isinstance(iprot.trans, TTransport.CReadableTransport) and self.thrift_spec is not None and fastbinary is not None:
      fastbinary.decode_binary(self, iprot.trans, (self.__class__, self.thrift_spec))
      return
    iprot.readStructBegin()
    while True:
      (fname, ftype, fid) = iprot.readFieldBegin()
      if ftype == TType.STOP:
        break
      if fid == 1:
        if ftype == TType.STRING:
          self.alternateURL = iprot.readString().decode('utf-8')
        else:
          iprot.skip(ftype)
      elif fid == 2:
        if ftype == TType.STRING:
          self.articleAbstract = iprot.readString().decode('utf-8')
        else:
          iprot.skip(ftype)
      elif fid == 3:
        if ftype == TType.STRING:
          self.authorBiography = iprot.readString().decode('utf-8')
        else:
          iprot.skip(ftype)
      elif fid == 4:
        if ftype == TType.STRING:
          self.banner = iprot.readString().decode('utf-8')
        else:
          iprot.skip(ftype)
      elif fid == 5:
        if ftype == TType.LIST:
          self.biographicalCategories = []
          (_etype3, _size0) = iprot.readListBegin()
          for _i4 in xrange(_size0):
            _elem5 = iprot.readString().decode('utf-8')
            self.biographicalCategories.append(_elem5)
          iprot.readListEnd()
        else:
          iprot.skip(ftype)
      elif fid == 6:
        if ftype == TType.STRING:
          self.body = iprot.readString().decode('utf-8')
        else:
          iprot.skip(ftype)
      elif fid == 7:
        if ftype == TType.STRING:
          self.byline = iprot.readString().decode('utf-8')
        else:
          iprot.skip(ftype)
      elif fid == 8:
        if ftype == TType.STRING:
          self.columnName = iprot.readString().decode('utf-8')
        else:
          iprot.skip(ftype)
      elif fid == 9:
        if ftype == TType.I32:
          self.columnNumber = iprot.readI32();
        else:
          iprot.skip(ftype)
      elif fid == 10:
        if ftype == TType.I64:
          self.correctionDate = iprot.readI64();
        else:
          iprot.skip(ftype)
      elif fid == 11:
        if ftype == TType.STRING:
          self.correctionText = iprot.readString().decode('utf-8')
        else:
          iprot.skip(ftype)
      elif fid == 12:
        if ftype == TType.STRING:
          self.credit = iprot.readString().decode('utf-8')
        else:
          iprot.skip(ftype)
      elif fid == 13:
        if ftype == TType.STRING:
          self.dateline = iprot.readString().decode('utf-8')
        else:
          iprot.skip(ftype)
      elif fid == 14:
        if ftype == TType.STRING:
          self.dayOfWeek = iprot.readString().decode('utf-8')
        else:
          iprot.skip(ftype)
      elif fid == 15:
        if ftype == TType.LIST:
          self.descriptors = []
          (_etype9, _size6) = iprot.readListBegin()
          for _i10 in xrange(_size6):
            _elem11 = iprot.readString().decode('utf-8')
            self.descriptors.append(_elem11)
          iprot.readListEnd()
        else:
          iprot.skip(ftype)
      elif fid == 16:
        if ftype == TType.STRING:
          self.featurePage = iprot.readString().decode('utf-8')
        else:
          iprot.skip(ftype)
      elif fid == 17:
        if ftype == TType.LIST:
          self.generalOnlineDescriptors = []
          (_etype15, _size12) = iprot.readListBegin()
          for _i16 in xrange(_size12):
            _elem17 = iprot.readString().decode('utf-8')
            self.generalOnlineDescriptors.append(_elem17)
          iprot.readListEnd()
        else:
          iprot.skip(ftype)
      elif fid == 18:
        if ftype == TType.I32:
          self.guid = iprot.readI32();
        else:
          iprot.skip(ftype)
      elif fid == 19:
        if ftype == TType.STRING:
          self.headline = iprot.readString().decode('utf-8')
        else:
          iprot.skip(ftype)
      elif fid == 20:
        if ftype == TType.STRING:
          self.kicker = iprot.readString().decode('utf-8')
        else:
          iprot.skip(ftype)
      elif fid == 21:
        if ftype == TType.STRING:
          self.leadParagraph = iprot.readString().decode('utf-8')
        else:
          iprot.skip(ftype)
      elif fid == 22:
        if ftype == TType.LIST:
          self.locations = []
          (_etype21, _size18) = iprot.readListBegin()
          for _i22 in xrange(_size18):
            _elem23 = iprot.readString().decode('utf-8')
            self.locations.append(_elem23)
          iprot.readListEnd()
        else:
          iprot.skip(ftype)
      elif fid == 23:
        if ftype == TType.LIST:
          self.names = []
          (_etype27, _size24) = iprot.readListBegin()
          for _i28 in xrange(_size24):
            _elem29 = iprot.readString().decode('utf-8')
            self.names.append(_elem29)
          iprot.readListEnd()
        else:
          iprot.skip(ftype)
      elif fid == 24:
        if ftype == TType.STRING:
          self.newsDesk = iprot.readString().decode('utf-8')
        else:
          iprot.skip(ftype)
      elif fid == 25:
        if ftype == TType.STRING:
          self.normalizedByline = iprot.readString().decode('utf-8')
        else:
          iprot.skip(ftype)
      elif fid == 26:
        if ftype == TType.LIST:
          self.onlineDescriptors = []
          (_etype33, _size30) = iprot.readListBegin()
          for _i34 in xrange(_size30):
            _elem35 = iprot.readString().decode('utf-8')
            self.onlineDescriptors.append(_elem35)
          iprot.readListEnd()
        else:
          iprot.skip(ftype)
      elif fid == 27:
        if ftype == TType.STRING:
          self.onlineHeadline = iprot.readString().decode('utf-8')
        else:
          iprot.skip(ftype)
      elif fid == 28:
        if ftype == TType.STRING:
          self.onlineLeadParagraph = iprot.readString().decode('utf-8')
        else:
          iprot.skip(ftype)
      elif fid == 29:
        if ftype == TType.LIST:
          self.onlineLocations = []
          (_etype39, _size36) = iprot.readListBegin()
          for _i40 in xrange(_size36):
            _elem41 = iprot.readString().decode('utf-8')
            self.onlineLocations.append(_elem41)
          iprot.readListEnd()
        else:
          iprot.skip(ftype)
      elif fid == 30:
        if ftype == TType.LIST:
          self.onlineOrganizations = []
          (_etype45, _size42) = iprot.readListBegin()
          for _i46 in xrange(_size42):
            _elem47 = iprot.readString().decode('utf-8')
            self.onlineOrganizations.append(_elem47)
          iprot.readListEnd()
        else:
          iprot.skip(ftype)
      elif fid == 31:
        if ftype == TType.LIST:
          self.onlinePeople = []
          (_etype51, _size48) = iprot.readListBegin()
          for _i52 in xrange(_size48):
            _elem53 = iprot.readString().decode('utf-8')
            self.onlinePeople.append(_elem53)
          iprot.readListEnd()
        else:
          iprot.skip(ftype)
      elif fid == 32:
        if ftype == TType.STRING:
          self.onlineSection = iprot.readString().decode('utf-8')
        else:
          iprot.skip(ftype)
      elif fid == 33:
        if ftype == TType.LIST:
          self.onlineTitles = []
          (_etype57, _size54) = iprot.readListBegin()
          for _i58 in xrange(_size54):
            _elem59 = iprot.readString().decode('utf-8')
            self.onlineTitles.append(_elem59)
          iprot.readListEnd()
        else:
          iprot.skip(ftype)
      elif fid == 34:
        if ftype == TType.LIST:
          self.organizations = []
          (_etype63, _size60) = iprot.readListBegin()
          for _i64 in xrange(_size60):
            _elem65 = iprot.readString().decode('utf-8')
            self.organizations.append(_elem65)
          iprot.readListEnd()
        else:
          iprot.skip(ftype)
      elif fid == 35:
        if ftype == TType.I32:
          self.page = iprot.readI32();
        else:
          iprot.skip(ftype)
      elif fid == 36:
        if ftype == TType.LIST:
          self.people = []
          (_etype69, _size66) = iprot.readListBegin()
          for _i70 in xrange(_size66):
            _elem71 = iprot.readString().decode('utf-8')
            self.people.append(_elem71)
          iprot.readListEnd()
        else:
          iprot.skip(ftype)
      elif fid == 37:
        if ftype == TType.I64:
          self.publicationDate = iprot.readI64();
        else:
          iprot.skip(ftype)
      elif fid == 38:
        if ftype == TType.I32:
          self.publicationDayOfMonth = iprot.readI32();
        else:
          iprot.skip(ftype)
      elif fid == 39:
        if ftype == TType.I32:
          self.publicationMonth = iprot.readI32();
        else:
          iprot.skip(ftype)
      elif fid == 40:
        if ftype == TType.I32:
          self.publicationYear = iprot.readI32();
        else:
          iprot.skip(ftype)
      elif fid == 41:
        if ftype == TType.STRING:
          self.section = iprot.readString().decode('utf-8')
        else:
          iprot.skip(ftype)
      elif fid == 42:
        if ftype == TType.STRING:
          self.seriesName = iprot.readString().decode('utf-8')
        else:
          iprot.skip(ftype)
      elif fid == 43:
        if ftype == TType.STRING:
          self.slug = iprot.readString().decode('utf-8')
        else:
          iprot.skip(ftype)
      elif fid == 44:
        if ftype == TType.STRING:
          self.sourceFilePath = iprot.readString().decode('utf-8')
        else:
          iprot.skip(ftype)
      elif fid == 45:
        if ftype == TType.LIST:
          self.taxonomicClassifiers = []
          (_etype75, _size72) = iprot.readListBegin()
          for _i76 in xrange(_size72):
            _elem77 = iprot.readString().decode('utf-8')
            self.taxonomicClassifiers.append(_elem77)
          iprot.readListEnd()
        else:
          iprot.skip(ftype)
      elif fid == 46:
        if ftype == TType.LIST:
          self.titles = []
          (_etype81, _size78) = iprot.readListBegin()
          for _i82 in xrange(_size78):
            _elem83 = iprot.readString().decode('utf-8')
            self.titles.append(_elem83)
          iprot.readListEnd()
        else:
          iprot.skip(ftype)
      elif fid == 47:
        if ftype == TType.LIST:
          self.typesOfMaterial = []
          (_etype87, _size84) = iprot.readListBegin()
          for _i88 in xrange(_size84):
            _elem89 = iprot.readString().decode('utf-8')
            self.typesOfMaterial.append(_elem89)
          iprot.readListEnd()
        else:
          iprot.skip(ftype)
      elif fid == 48:
        if ftype == TType.STRING:
          self.url = iprot.readString().decode('utf-8')
        else:
          iprot.skip(ftype)
      elif fid == 49:
        if ftype == TType.I32:
          self.wordCount = iprot.readI32();
        else:
          iprot.skip(ftype)
      else:
        iprot.skip(ftype)
      iprot.readFieldEnd()
    iprot.readStructEnd()

  def write(self, oprot):
    if oprot.__class__ == TBinaryProtocol.TBinaryProtocolAccelerated and self.thrift_spec is not None and fastbinary is not None:
      oprot.trans.write(fastbinary.encode_binary(self, (self.__class__, self.thrift_spec)))
      return
    oprot.writeStructBegin('NITFInfo')
    if self.alternateURL is not None:
      oprot.writeFieldBegin('alternateURL', TType.STRING, 1)
      oprot.writeString(self.alternateURL.encode('utf-8'))
      oprot.writeFieldEnd()
    if self.articleAbstract is not None:
      oprot.writeFieldBegin('articleAbstract', TType.STRING, 2)
      oprot.writeString(self.articleAbstract.encode('utf-8'))
      oprot.writeFieldEnd()
    if self.authorBiography is not None:
      oprot.writeFieldBegin('authorBiography', TType.STRING, 3)
      oprot.writeString(self.authorBiography.encode('utf-8'))
      oprot.writeFieldEnd()
    if self.banner is not None:
      oprot.writeFieldBegin('banner', TType.STRING, 4)
      oprot.writeString(self.banner.encode('utf-8'))
      oprot.writeFieldEnd()
    if self.biographicalCategories is not None:
      oprot.writeFieldBegin('biographicalCategories', TType.LIST, 5)
      oprot.writeListBegin(TType.STRING, len(self.biographicalCategories))
      for iter90 in self.biographicalCategories:
        oprot.writeString(iter90.encode('utf-8'))
      oprot.writeListEnd()
      oprot.writeFieldEnd()
    if self.body is not None:
      oprot.writeFieldBegin('body', TType.STRING, 6)
      oprot.writeString(self.body.encode('utf-8'))
      oprot.writeFieldEnd()
    if self.byline is not None:
      oprot.writeFieldBegin('byline', TType.STRING, 7)
      oprot.writeString(self.byline.encode('utf-8'))
      oprot.writeFieldEnd()
    if self.columnName is not None:
      oprot.writeFieldBegin('columnName', TType.STRING, 8)
      oprot.writeString(self.columnName.encode('utf-8'))
      oprot.writeFieldEnd()
    if self.columnNumber is not None:
      oprot.writeFieldBegin('columnNumber', TType.I32, 9)
      oprot.writeI32(self.columnNumber)
      oprot.writeFieldEnd()
    if self.correctionDate is not None:
      oprot.writeFieldBegin('correctionDate', TType.I64, 10)
      oprot.writeI64(self.correctionDate)
      oprot.writeFieldEnd()
    if self.correctionText is not None:
      oprot.writeFieldBegin('correctionText', TType.STRING, 11)
      oprot.writeString(self.correctionText.encode('utf-8'))
      oprot.writeFieldEnd()
    if self.credit is not None:
      oprot.writeFieldBegin('credit', TType.STRING, 12)
      oprot.writeString(self.credit.encode('utf-8'))
      oprot.writeFieldEnd()
    if self.dateline is not None:
      oprot.writeFieldBegin('dateline', TType.STRING, 13)
      oprot.writeString(self.dateline.encode('utf-8'))
      oprot.writeFieldEnd()
    if self.dayOfWeek is not None:
      oprot.writeFieldBegin('dayOfWeek', TType.STRING, 14)
      oprot.writeString(self.dayOfWeek.encode('utf-8'))
      oprot.writeFieldEnd()
    if self.descriptors is not None:
      oprot.writeFieldBegin('descriptors', TType.LIST, 15)
      oprot.writeListBegin(TType.STRING, len(self.descriptors))
      for iter91 in self.descriptors:
        oprot.writeString(iter91.encode('utf-8'))
      oprot.writeListEnd()
      oprot.writeFieldEnd()
    if self.featurePage is not None:
      oprot.writeFieldBegin('featurePage', TType.STRING, 16)
      oprot.writeString(self.featurePage.encode('utf-8'))
      oprot.writeFieldEnd()
    if self.generalOnlineDescriptors is not None:
      oprot.writeFieldBegin('generalOnlineDescriptors', TType.LIST, 17)
      oprot.writeListBegin(TType.STRING, len(self.generalOnlineDescriptors))
      for iter92 in self.generalOnlineDescriptors:
        oprot.writeString(iter92.encode('utf-8'))
      oprot.writeListEnd()
      oprot.writeFieldEnd()
    if self.guid is not None:
      oprot.writeFieldBegin('guid', TType.I32, 18)
      oprot.writeI32(self.guid)
      oprot.writeFieldEnd()
    if self.headline is not None:
      oprot.writeFieldBegin('headline', TType.STRING, 19)
      oprot.writeString(self.headline.encode('utf-8'))
      oprot.writeFieldEnd()
    if self.kicker is not None:
      oprot.writeFieldBegin('kicker', TType.STRING, 20)
      oprot.writeString(self.kicker.encode('utf-8'))
      oprot.writeFieldEnd()
    if self.leadParagraph is not None:
      oprot.writeFieldBegin('leadParagraph', TType.STRING, 21)
      oprot.writeString(self.leadParagraph.encode('utf-8'))
      oprot.writeFieldEnd()
    if self.locations is not None:
      oprot.writeFieldBegin('locations', TType.LIST, 22)
      oprot.writeListBegin(TType.STRING, len(self.locations))
      for iter93 in self.locations:
        oprot.writeString(iter93.encode('utf-8'))
      oprot.writeListEnd()
      oprot.writeFieldEnd()
    if self.names is not None:
      oprot.writeFieldBegin('names', TType.LIST, 23)
      oprot.writeListBegin(TType.STRING, len(self.names))
      for iter94 in self.names:
        oprot.writeString(iter94.encode('utf-8'))
      oprot.writeListEnd()
      oprot.writeFieldEnd()
    if self.newsDesk is not None:
      oprot.writeFieldBegin('newsDesk', TType.STRING, 24)
      oprot.writeString(self.newsDesk.encode('utf-8'))
      oprot.writeFieldEnd()
    if self.normalizedByline is not None:
      oprot.writeFieldBegin('normalizedByline', TType.STRING, 25)
      oprot.writeString(self.normalizedByline.encode('utf-8'))
      oprot.writeFieldEnd()
    if self.onlineDescriptors is not None:
      oprot.writeFieldBegin('onlineDescriptors', TType.LIST, 26)
      oprot.writeListBegin(TType.STRING, len(self.onlineDescriptors))
      for iter95 in self.onlineDescriptors:
        oprot.writeString(iter95.encode('utf-8'))
      oprot.writeListEnd()
      oprot.writeFieldEnd()
    if self.onlineHeadline is not None:
      oprot.writeFieldBegin('onlineHeadline', TType.STRING, 27)
      oprot.writeString(self.onlineHeadline.encode('utf-8'))
      oprot.writeFieldEnd()
    if self.onlineLeadParagraph is not None:
      oprot.writeFieldBegin('onlineLeadParagraph', TType.STRING, 28)
      oprot.writeString(self.onlineLeadParagraph.encode('utf-8'))
      oprot.writeFieldEnd()
    if self.onlineLocations is not None:
      oprot.writeFieldBegin('onlineLocations', TType.LIST, 29)
      oprot.writeListBegin(TType.STRING, len(self.onlineLocations))
      for iter96 in self.onlineLocations:
        oprot.writeString(iter96.encode('utf-8'))
      oprot.writeListEnd()
      oprot.writeFieldEnd()
    if self.onlineOrganizations is not None:
      oprot.writeFieldBegin('onlineOrganizations', TType.LIST, 30)
      oprot.writeListBegin(TType.STRING, len(self.onlineOrganizations))
      for iter97 in self.onlineOrganizations:
        oprot.writeString(iter97.encode('utf-8'))
      oprot.writeListEnd()
      oprot.writeFieldEnd()
    if self.onlinePeople is not None:
      oprot.writeFieldBegin('onlinePeople', TType.LIST, 31)
      oprot.writeListBegin(TType.STRING, len(self.onlinePeople))
      for iter98 in self.onlinePeople:
        oprot.writeString(iter98.encode('utf-8'))
      oprot.writeListEnd()
      oprot.writeFieldEnd()
    if self.onlineSection is not None:
      oprot.writeFieldBegin('onlineSection', TType.STRING, 32)
      oprot.writeString(self.onlineSection.encode('utf-8'))
      oprot.writeFieldEnd()
    if self.onlineTitles is not None:
      oprot.writeFieldBegin('onlineTitles', TType.LIST, 33)
      oprot.writeListBegin(TType.STRING, len(self.onlineTitles))
      for iter99 in self.onlineTitles:
        oprot.writeString(iter99.encode('utf-8'))
      oprot.writeListEnd()
      oprot.writeFieldEnd()
    if self.organizations is not None:
      oprot.writeFieldBegin('organizations', TType.LIST, 34)
      oprot.writeListBegin(TType.STRING, len(self.organizations))
      for iter100 in self.organizations:
        oprot.writeString(iter100.encode('utf-8'))
      oprot.writeListEnd()
      oprot.writeFieldEnd()
    if self.page is not None:
      oprot.writeFieldBegin('page', TType.I32, 35)
      oprot.writeI32(self.page)
      oprot.writeFieldEnd()
    if self.people is not None:
      oprot.writeFieldBegin('people', TType.LIST, 36)
      oprot.writeListBegin(TType.STRING, len(self.people))
      for iter101 in self.people:
        oprot.writeString(iter101.encode('utf-8'))
      oprot.writeListEnd()
      oprot.writeFieldEnd()
    if self.publicationDate is not None:
      oprot.writeFieldBegin('publicationDate', TType.I64, 37)
      oprot.writeI64(self.publicationDate)
      oprot.writeFieldEnd()
    if self.publicationDayOfMonth is not None:
      oprot.writeFieldBegin('publicationDayOfMonth', TType.I32, 38)
      oprot.writeI32(self.publicationDayOfMonth)
      oprot.writeFieldEnd()
    if self.publicationMonth is not None:
      oprot.writeFieldBegin('publicationMonth', TType.I32, 39)
      oprot.writeI32(self.publicationMonth)
      oprot.writeFieldEnd()
    if self.publicationYear is not None:
      oprot.writeFieldBegin('publicationYear', TType.I32, 40)
      oprot.writeI32(self.publicationYear)
      oprot.writeFieldEnd()
    if self.section is not None:
      oprot.writeFieldBegin('section', TType.STRING, 41)
      oprot.writeString(self.section.encode('utf-8'))
      oprot.writeFieldEnd()
    if self.seriesName is not None:
      oprot.writeFieldBegin('seriesName', TType.STRING, 42)
      oprot.writeString(self.seriesName.encode('utf-8'))
      oprot.writeFieldEnd()
    if self.slug is not None:
      oprot.writeFieldBegin('slug', TType.STRING, 43)
      oprot.writeString(self.slug.encode('utf-8'))
      oprot.writeFieldEnd()
    if self.sourceFilePath is not None:
      oprot.writeFieldBegin('sourceFilePath', TType.STRING, 44)
      oprot.writeString(self.sourceFilePath.encode('utf-8'))
      oprot.writeFieldEnd()
    if self.taxonomicClassifiers is not None:
      oprot.writeFieldBegin('taxonomicClassifiers', TType.LIST, 45)
      oprot.writeListBegin(TType.STRING, len(self.taxonomicClassifiers))
      for iter102 in self.taxonomicClassifiers:
        oprot.writeString(iter102.encode('utf-8'))
      oprot.writeListEnd()
      oprot.writeFieldEnd()
    if self.titles is not None:
      oprot.writeFieldBegin('titles', TType.LIST, 46)
      oprot.writeListBegin(TType.STRING, len(self.titles))
      for iter103 in self.titles:
        oprot.writeString(iter103.encode('utf-8'))
      oprot.writeListEnd()
      oprot.writeFieldEnd()
    if self.typesOfMaterial is not None:
      oprot.writeFieldBegin('typesOfMaterial', TType.LIST, 47)
      oprot.writeListBegin(TType.STRING, len(self.typesOfMaterial))
      for iter104 in self.typesOfMaterial:
        oprot.writeString(iter104.encode('utf-8'))
      oprot.writeListEnd()
      oprot.writeFieldEnd()
    if self.url is not None:
      oprot.writeFieldBegin('url', TType.STRING, 48)
      oprot.writeString(self.url.encode('utf-8'))
      oprot.writeFieldEnd()
    if self.wordCount is not None:
      oprot.writeFieldBegin('wordCount', TType.I32, 49)
      oprot.writeI32(self.wordCount)
      oprot.writeFieldEnd()
    oprot.writeFieldStop()
    oprot.writeStructEnd()

  def validate(self):
    return


  def __repr__(self):
    L = ['%s=%r' % (key, value)
      for key, value in self.__dict__.iteritems()]
    return '%s(%s)' % (self.__class__.__name__, ', '.join(L))

  def __eq__(self, other):
    return isinstance(other, self.__class__) and self.__dict__ == other.__dict__

  def __ne__(self, other):
    return not (self == other)



#
# Autogenerated by Thrift Compiler (1.0.0-dev)
#
# DO NOT EDIT UNLESS YOU ARE SURE THAT YOU KNOW WHAT YOU ARE DOING
#
#  options string: py:new_style,utf8strings
#

from thrift.Thrift import TType, TMessageType, TException, TApplicationException

from thrift.transport import TTransport
from thrift.protocol import TBinaryProtocol, TProtocol
try:
  from thrift.protocol import fastbinary
except:
  fastbinary = None



class TwitterUser(object):
  """
  Information about a Twitter user.

  Attributes:
   - id
   - name
   - screenName
   - lang
   - geoEnabled
   - createdAt
   - friendsCount
   - statusesCount
   - verified
   - listedCount
   - favouritesCount
   - followersCount
   - location
   - timeZone
   - description
   - utcOffset
   - url
  """

  thrift_spec = (
    None, # 0
    (1, TType.I64, 'id', None, None, ), # 1
    None, # 2
    (3, TType.STRING, 'name', None, None, ), # 3
    (4, TType.STRING, 'screenName', None, None, ), # 4
    (5, TType.STRING, 'lang', None, None, ), # 5
    (6, TType.BOOL, 'geoEnabled', None, None, ), # 6
    (7, TType.STRING, 'createdAt', None, None, ), # 7
    (8, TType.I32, 'friendsCount', None, None, ), # 8
    (9, TType.I32, 'statusesCount', None, None, ), # 9
    (10, TType.BOOL, 'verified', None, None, ), # 10
    (11, TType.I32, 'listedCount', None, None, ), # 11
    (12, TType.I32, 'favouritesCount', None, None, ), # 12
    (13, TType.I32, 'followersCount', None, None, ), # 13
    (14, TType.STRING, 'location', None, None, ), # 14
    (15, TType.STRING, 'timeZone', None, None, ), # 15
    (16, TType.STRING, 'description', None, None, ), # 16
    None, # 17
    (18, TType.I32, 'utcOffset', None, None, ), # 18
    (19, TType.STRING, 'url', None, None, ), # 19
  )

  def __init__(self, id=None, name=None, screenName=None, lang=None, geoEnabled=None, createdAt=None, friendsCount=None, statusesCount=None, verified=None, listedCount=None, favouritesCount=None, followersCount=None, location=None, timeZone=None, description=None, utcOffset=None, url=None,):
    self.id = id
    self.name = name
    self.screenName = screenName
    self.lang = lang
    self.geoEnabled = geoEnabled
    self.createdAt = createdAt
    self.friendsCount = friendsCount
    self.statusesCount = statusesCount
    self.verified = verified
    self.listedCount = listedCount
    self.favouritesCount = favouritesCount
    self.followersCount = followersCount
    self.location = location
    self.timeZone = timeZone
    self.description = description
    self.utcOffset = utcOffset
    self.url = url

  def read(self, iprot):
    if iprot.__class__ == TBinaryProtocol.TBinaryProtocolAccelerated and isinstance(iprot.trans, TTransport.CReadableTransport) and self.thrift_spec is not None and fastbinary is not None:
      fastbinary.decode_binary(self, iprot.trans, (self.__class__, self.thrift_spec))
      return
    iprot.readStructBegin()
    while True:
      (fname, ftype, fid) = iprot.readFieldBegin()
      if ftype == TType.STOP:
        break
      if fid == 1:
        if ftype == TType.I64:
          self.id = iprot.readI64();
        else:
          iprot.skip(ftype)
      elif fid == 3:
        if ftype == TType.STRING:
          self.name = iprot.readString().decode('utf-8')
        else:
          iprot.skip(ftype)
      elif fid == 4:
        if ftype == TType.STRING:
          self.screenName = iprot.readString().decode('utf-8')
        else:
          iprot.skip(ftype)
      elif fid == 5:
        if ftype == TType.STRING:
          self.lang = iprot.readString().decode('utf-8')
        else:
          iprot.skip(ftype)
      elif fid == 6:
        if ftype == TType.BOOL:
          self.geoEnabled = iprot.readBool();
        else:
          iprot.skip(ftype)
      elif fid == 7:
        if ftype == TType.STRING:
          self.createdAt = iprot.readString().decode('utf-8')
        else:
          iprot.skip(ftype)
      elif fid == 8:
        if ftype == TType.I32:
          self.friendsCount = iprot.readI32();
        else:
          iprot.skip(ftype)
      elif fid == 9:
        if ftype == TType.I32:
          self.statusesCount = iprot.readI32();
        else:
          iprot.skip(ftype)
      elif fid == 10:
        if ftype == TType.BOOL:
          self.verified = iprot.readBool();
        else:
          iprot.skip(ftype)
      elif fid == 11:
        if ftype == TType.I32:
          self.listedCount = iprot.readI32();
        else:
          iprot.skip(ftype)
      elif fid == 12:
        if ftype == TType.I32:
          self.favouritesCount = iprot.readI32();
        else:
          iprot.skip(ftype)
      elif fid == 13:
        if ftype == TType.I32:
          self.followersCount = iprot.readI32();
        else:
          iprot.skip(ftype)
      elif fid == 14:
        if ftype == TType.STRING:
          self.location = iprot.readString().decode('utf-8')
        else:
          iprot.skip(ftype)
      elif fid == 15:
        if ftype == TType.STRING:
          self.timeZone = iprot.readString().decode('utf-8')
        else:
          iprot.skip(ftype)
      elif fid == 16:
        if ftype == TType.STRING:
          self.description = iprot.readString().decode('utf-8')
        else:
          iprot.skip(ftype)
      elif fid == 18:
        if ftype == TType.I32:
          self.utcOffset = iprot.readI32();
        else:
          iprot.skip(ftype)
      elif fid == 19:
        if ftype == TType.STRING:
          self.url = iprot.readString().decode('utf-8')
        else:
          iprot.skip(ftype)
      else:
        iprot.skip(ftype)
      iprot.readFieldEnd()
    iprot.readStructEnd()

  def write(self, oprot):
    if oprot.__class__ == TBinaryProtocol.TBinaryProtocolAccelerated and self.thrift_spec is not None and fastbinary is not None:
      oprot.trans.write(fastbinary.encode_binary(self, (self.__class__, self.thrift_spec)))
      return
    oprot.writeStructBegin('TwitterUser')
    if self.id is not None:
      oprot.writeFieldBegin('id', TType.I64, 1)
      oprot.writeI64(self.id)
      oprot.writeFieldEnd()
    if self.name is not None:
      oprot.writeFieldBegin('name', TType.STRING, 3)
      oprot.writeString(self.name.encode('utf-8'))
      oprot.writeFieldEnd()
    if self.screenName is not None:
      oprot.writeFieldBegin('screenName', TType.STRING, 4)
      oprot.writeString(self.screenName.encode('utf-8'))
      oprot.writeFieldEnd()
    if self.lang is not None:
      oprot.writeFieldBegin('lang', TType.STRING, 5)
      oprot.writeString(self.lang.encode('utf-8'))
      oprot.writeFieldEnd()
    if self.geoEnabled is not None:
      oprot.writeFieldBegin('geoEnabled', TType.BOOL, 6)
      oprot.writeBool(self.geoEnabled)
      oprot.writeFieldEnd()
    if self.createdAt is not None:
      oprot.writeFieldBegin('createdAt', TType.STRING, 7)
      oprot.writeString(self.createdAt.encode('utf-8'))
      oprot.writeFieldEnd()
    if self.friendsCount is not None:
      oprot.writeFieldBegin('friendsCount', TType.I32, 8)
      oprot.writeI32(self.friendsCount)
      oprot.writeFieldEnd()
    if self.statusesCount is not None:
      oprot.writeFieldBegin('statusesCount', TType.I32, 9)
      oprot.writeI32(self.statusesCount)
      oprot.writeFieldEnd()
    if self.verified is not None:
      oprot.writeFieldBegin('verified', TType.BOOL, 10)
      oprot.writeBool(self.verified)
      oprot.writeFieldEnd()
    if self.listedCount is not None:
      oprot.writeFieldBegin('listedCount', TType.I32, 11)
      oprot.writeI32(self.listedCount)
      oprot.writeFieldEnd()
    if self.favouritesCount is not None:
      oprot.writeFieldBegin('favouritesCount', TType.I32, 12)
      oprot.writeI32(self.favouritesCount)
      oprot.writeFieldEnd()
    if self.followersCount is not None:
      oprot.writeFieldBegin('followersCount', TType.I32, 13)
      oprot.writeI32(self.followersCount)
      oprot.writeFieldEnd()
    if self.location is not None:
      oprot.writeFieldBegin('location', TType.STRING, 14)
      oprot.writeString(self.location.encode('utf-8'))
      oprot.writeFieldEnd()
    if self.timeZone is not None:
      oprot.writeFieldBegin('timeZone', TType.STRING, 15)
      oprot.writeString(self.timeZone.encode('utf-8'))
      oprot.writeFieldEnd()
    if self.description is not None:
      oprot.writeFieldBegin('description', TType.STRING, 16)
      oprot.writeString(self.description.encode('utf-8'))
      oprot.writeFieldEnd()
    if self.utcOffset is not None:
      oprot.writeFieldBegin('utcOffset', TType.I32, 18)
      oprot.writeI32(self.utcOffset)
      oprot.writeFieldEnd()
    if self.url is not None:
      oprot.writeFieldBegin('url', TType.STRING, 19)
      oprot.writeString(self.url.encode('utf-8'))
      oprot.writeFieldEnd()
    oprot.writeFieldStop()
    oprot.writeStructEnd()

  def validate(self):
    return


  def __repr__(self):
    L = ['%s=%r' % (key, value)
      for key, value in self.__dict__.iteritems()]
    return '%s(%s)' % (self.__class__.__name__, ', '.join(L))

  def __eq__(self, other):
    return isinstance(other, self.__class__) and self.__dict__ == other.__dict__

  def __ne__(self, other):
    return not (self == other)

class TwitterLatLong(object):
  """
  A twitter geocoordinate.

  Attributes:
   - latitude
   - longitude
  """

  thrift_spec = (
    None, # 0
    (1, TType.DOUBLE, 'latitude', None, None, ), # 1
    (2, TType.DOUBLE, 'longitude', None, None, ), # 2
  )

  def __init__(self, latitude=None, longitude=None,):
    self.latitude = latitude
    self.longitude = longitude

  def read(self, iprot):
    if iprot.__class__ == TBinaryProtocol.TBinaryProtocolAccelerated and isinstance(iprot.trans, TTransport.CReadableTransport) and self.thrift_spec is not None and fastbinary is not None:
      fastbinary.decode_binary(self, iprot.trans, (self.__class__, self.thrift_spec))
      return
    iprot.readStructBegin()
    while True:
      (fname, ftype, fid) = iprot.readFieldBegin()
      if ftype == TType.STOP:
        break
      if fid == 1:
        if ftype == TType.DOUBLE:
          self.latitude = iprot.readDouble();
        else:
          iprot.skip(ftype)
      elif fid == 2:
        if ftype == TType.DOUBLE:
          self.longitude = iprot.readDouble();
        else:
          iprot.skip(ftype)
      else:
        iprot.skip(ftype)
      iprot.readFieldEnd()
    iprot.readStructEnd()

  def write(self, oprot):
    if oprot.__class__ == TBinaryProtocol.TBinaryProtocolAccelerated and self.thrift_spec is not None and fastbinary is not None:
      oprot.trans.write(fastbinary.encode_binary(self, (self.__class__, self.thrift_spec)))
      return
    oprot.writeStructBegin('TwitterLatLong')
    if self.latitude is not None:
      oprot.writeFieldBegin('latitude', TType.DOUBLE, 1)
      oprot.writeDouble(self.latitude)
      oprot.writeFieldEnd()
    if self.longitude is not None:
      oprot.writeFieldBegin('longitude', TType.DOUBLE, 2)
      oprot.writeDouble(self.longitude)
      oprot.writeFieldEnd()
    oprot.writeFieldStop()
    oprot.writeStructEnd()

  def validate(self):
    return


  def __repr__(self):
    L = ['%s=%r' % (key, value)
      for key, value in self.__dict__.iteritems()]
    return '%s(%s)' % (self.__class__.__name__, ', '.join(L))

  def __eq__(self, other):
    return isinstance(other, self.__class__) and self.__dict__ == other.__dict__

  def __ne__(self, other):
    return not (self == other)

class BoundingBox(object):
  """
  Attributes:
   - type
   - coordinates
  """

  thrift_spec = (
    None, # 0
    (1, TType.STRING, 'type', None, None, ), # 1
    (2, TType.LIST, 'coordinates', (TType.STRUCT,(TwitterLatLong, TwitterLatLong.thrift_spec)), None, ), # 2
  )

  def __init__(self, type=None, coordinates=None,):
    self.type = type
    self.coordinates = coordinates

  def read(self, iprot):
    if iprot.__class__ == TBinaryProtocol.TBinaryProtocolAccelerated and isinstance(iprot.trans, TTransport.CReadableTransport) and self.thrift_spec is not None and fastbinary is not None:
      fastbinary.decode_binary(self, iprot.trans, (self.__class__, self.thrift_spec))
      return
    iprot.readStructBegin()
    while True:
      (fname, ftype, fid) = iprot.readFieldBegin()
      if ftype == TType.STOP:
        break
      if fid == 1:
        if ftype == TType.STRING:
          self.type = iprot.readString().decode('utf-8')
        else:
          iprot.skip(ftype)
      elif fid == 2:
        if ftype == TType.LIST:
          self.coordinates = []
          (_etype3, _size0) = iprot.readListBegin()
          for _i4 in xrange(_size0):
            _elem5 = TwitterLatLong()
            _elem5.read(iprot)
            self.coordinates.append(_elem5)
          iprot.readListEnd()
        else:
          iprot.skip(ftype)
      else:
        iprot.skip(ftype)
      iprot.readFieldEnd()
    iprot.readStructEnd()

  def write(self, oprot):
    if oprot.__class__ == TBinaryProtocol.TBinaryProtocolAccelerated and self.thrift_spec is not None and fastbinary is not None:
      oprot.trans.write(fastbinary.encode_binary(self, (self.__class__, self.thrift_spec)))
      return
    oprot.writeStructBegin('BoundingBox')
    if self.type is not None:
      oprot.writeFieldBegin('type', TType.STRING, 1)
      oprot.writeString(self.type.encode('utf-8'))
      oprot.writeFieldEnd()
    if self.coordinates is not None:
      oprot.writeFieldBegin('coordinates', TType.LIST, 2)
      oprot.writeListBegin(TType.STRUCT, len(self.coordinates))
      for iter6 in self.coordinates:
        iter6.write(oprot)
      oprot.writeListEnd()
      oprot.writeFieldEnd()
    oprot.writeFieldStop()
    oprot.writeStructEnd()

  def validate(self):
    if self.coordinates is None:
      raise TProtocol.TProtocolException(message='Required field coordinates is unset!')
    return


  def __repr__(self):
    L = ['%s=%r' % (key, value)
      for key, value in self.__dict__.iteritems()]
    return '%s(%s)' % (self.__class__.__name__, ', '.join(L))

  def __eq__(self, other):
    return isinstance(other, self.__class__) and self.__dict__ == other.__dict__

  def __ne__(self, other):
    return not (self == other)

class PlaceAttributes(object):
  """
  Attributes:
   - streetAddress
   - region
   - locality
  """

  thrift_spec = (
    None, # 0
    (1, TType.STRING, 'streetAddress', None, None, ), # 1
    (2, TType.STRING, 'region', None, None, ), # 2
    (3, TType.STRING, 'locality', None, None, ), # 3
  )

  def __init__(self, streetAddress=None, region=None, locality=None,):
    self.streetAddress = streetAddress
    self.region = region
    self.locality = locality

  def read(self, iprot):
    if iprot.__class__ == TBinaryProtocol.TBinaryProtocolAccelerated and isinstance(iprot.trans, TTransport.CReadableTransport) and self.thrift_spec is not None and fastbinary is not None:
      fastbinary.decode_binary(self, iprot.trans, (self.__class__, self.thrift_spec))
      return
    iprot.readStructBegin()
    while True:
      (fname, ftype, fid) = iprot.readFieldBegin()
      if ftype == TType.STOP:
        break
      if fid == 1:
        if ftype == TType.STRING:
          self.streetAddress = iprot.readString().decode('utf-8')
        else:
          iprot.skip(ftype)
      elif fid == 2:
        if ftype == TType.STRING:
          self.region = iprot.readString().decode('utf-8')
        else:
          iprot.skip(ftype)
      elif fid == 3:
        if ftype == TType.STRING:
          self.locality = iprot.readString().decode('utf-8')
        else:
          iprot.skip(ftype)
      else:
        iprot.skip(ftype)
      iprot.readFieldEnd()
    iprot.readStructEnd()

  def write(self, oprot):
    if oprot.__class__ == TBinaryProtocol.TBinaryProtocolAccelerated and self.thrift_spec is not None and fastbinary is not None:
      oprot.trans.write(fastbinary.encode_binary(self, (self.__class__, self.thrift_spec)))
      return
    oprot.writeStructBegin('PlaceAttributes')
    if self.streetAddress is not None:
      oprot.writeFieldBegin('streetAddress', TType.STRING, 1)
      oprot.writeString(self.streetAddress.encode('utf-8'))
      oprot.writeFieldEnd()
    if self.region is not None:
      oprot.writeFieldBegin('region', TType.STRING, 2)
      oprot.writeString(self.region.encode('utf-8'))
      oprot.writeFieldEnd()
    if self.locality is not None:
      oprot.writeFieldBegin('locality', TType.STRING, 3)
      oprot.writeString(self.locality.encode('utf-8'))
      oprot.writeFieldEnd()
    oprot.writeFieldStop()
    oprot.writeStructEnd()

  def validate(self):
    return


  def __repr__(self):
    L = ['%s=%r' % (key, value)
      for key, value in self.__dict__.iteritems()]
    return '%s(%s)' % (self.__class__.__name__, ', '.join(L))

  def __eq__(self, other):
    return isinstance(other, self.__class__) and self.__dict__ == other.__dict__

  def __ne__(self, other):
    return not (self == other)

class UserMention(object):
  """
  Attributes:
   - startOffset
   - endOffset
   - screenName
   - name
   - id
  """

  thrift_spec = (
    None, # 0
    (1, TType.I32, 'startOffset', None, None, ), # 1
    (2, TType.I32, 'endOffset', None, None, ), # 2
    None, # 3
    (4, TType.STRING, 'screenName', None, None, ), # 4
    (5, TType.STRING, 'name', None, None, ), # 5
    (6, TType.I64, 'id', None, None, ), # 6
  )

  def __init__(self, startOffset=None, endOffset=None, screenName=None, name=None, id=None,):
    self.startOffset = startOffset
    self.endOffset = endOffset
    self.screenName = screenName
    self.name = name
    self.id = id

  def read(self, iprot):
    if iprot.__class__ == TBinaryProtocol.TBinaryProtocolAccelerated and isinstance(iprot.trans, TTransport.CReadableTransport) and self.thrift_spec is not None and fastbinary is not None:
      fastbinary.decode_binary(self, iprot.trans, (self.__class__, self.thrift_spec))
      return
    iprot.readStructBegin()
    while True:
      (fname, ftype, fid) = iprot.readFieldBegin()
      if ftype == TType.STOP:
        break
      if fid == 1:
        if ftype == TType.I32:
          self.startOffset = iprot.readI32();
        else:
          iprot.skip(ftype)
      elif fid == 2:
        if ftype == TType.I32:
          self.endOffset = iprot.readI32();
        else:
          iprot.skip(ftype)
      elif fid == 4:
        if ftype == TType.STRING:
          self.screenName = iprot.readString().decode('utf-8')
        else:
          iprot.skip(ftype)
      elif fid == 5:
        if ftype == TType.STRING:
          self.name = iprot.readString().decode('utf-8')
        else:
          iprot.skip(ftype)
      elif fid == 6:
        if ftype == TType.I64:
          self.id = iprot.readI64();
        else:
          iprot.skip(ftype)
      else:
        iprot.skip(ftype)
      iprot.readFieldEnd()
    iprot.readStructEnd()

  def write(self, oprot):
    if oprot.__class__ == TBinaryProtocol.TBinaryProtocolAccelerated and self.thrift_spec is not None and fastbinary is not None:
      oprot.trans.write(fastbinary.encode_binary(self, (self.__class__, self.thrift_spec)))
      return
    oprot.writeStructBegin('UserMention')
    if self.startOffset is not None:
      oprot.writeFieldBegin('startOffset', TType.I32, 1)
      oprot.writeI32(self.startOffset)
      oprot.writeFieldEnd()
    if self.endOffset is not None:
      oprot.writeFieldBegin('endOffset', TType.I32, 2)
      oprot.writeI32(self.endOffset)
      oprot.writeFieldEnd()
    if self.screenName is not None:
      oprot.writeFieldBegin('screenName', TType.STRING, 4)
      oprot.writeString(self.screenName.encode('utf-8'))
      oprot.writeFieldEnd()
    if self.name is not None:
      oprot.writeFieldBegin('name', TType.STRING, 5)
      oprot.writeString(self.name.encode('utf-8'))
      oprot.writeFieldEnd()
    if self.id is not None:
      oprot.writeFieldBegin('id', TType.I64, 6)
      oprot.writeI64(self.id)
      oprot.writeFieldEnd()
    oprot.writeFieldStop()
    oprot.writeStructEnd()

  def validate(self):
    return


  def __repr__(self):
    L = ['%s=%r' % (key, value)
      for key, value in self.__dict__.iteritems()]
    return '%s(%s)' % (self.__class__.__name__, ', '.join(L))

  def __eq__(self, other):
    return isinstance(other, self.__class__) and self.__dict__ == other.__dict__

  def __ne__(self, other):
    return not (self == other)

class URL(object):
  """
  Attributes:
   - startOffset
   - endOffset
   - expandedUrl
   - url
   - displayUrl
  """

  thrift_spec = (
    None, # 0
    (1, TType.I32, 'startOffset', None, None, ), # 1
    (2, TType.I32, 'endOffset', None, None, ), # 2
    (3, TType.STRING, 'expandedUrl', None, None, ), # 3
    (4, TType.STRING, 'url', None, None, ), # 4
    (5, TType.STRING, 'displayUrl', None, None, ), # 5
  )

  def __init__(self, startOffset=None, endOffset=None, expandedUrl=None, url=None, displayUrl=None,):
    self.startOffset = startOffset
    self.endOffset = endOffset
    self.expandedUrl = expandedUrl
    self.url = url
    self.displayUrl = displayUrl

  def read(self, iprot):
    if iprot.__class__ == TBinaryProtocol.TBinaryProtocolAccelerated and isinstance(iprot.trans, TTransport.CReadableTransport) and self.thrift_spec is not None and fastbinary is not None:
      fastbinary.decode_binary(self, iprot.trans, (self.__class__, self.thrift_spec))
      return
    iprot.readStructBegin()
    while True:
      (fname, ftype, fid) = iprot.readFieldBegin()
      if ftype == TType.STOP:
        break
      if fid == 1:
        if ftype == TType.I32:
          self.startOffset = iprot.readI32();
        else:
          iprot.skip(ftype)
      elif fid == 2:
        if ftype == TType.I32:
          self.endOffset = iprot.readI32();
        else:
          iprot.skip(ftype)
      elif fid == 3:
        if ftype == TType.STRING:
          self.expandedUrl = iprot.readString().decode('utf-8')
        else:
          iprot.skip(ftype)
      elif fid == 4:
        if ftype == TType.STRING:
          self.url = iprot.readString().decode('utf-8')
        else:
          iprot.skip(ftype)
      elif fid == 5:
        if ftype == TType.STRING:
          self.displayUrl = iprot.readString().decode('utf-8')
        else:
          iprot.skip(ftype)
      else:
        iprot.skip(ftype)
      iprot.readFieldEnd()
    iprot.readStructEnd()

  def write(self, oprot):
    if oprot.__class__ == TBinaryProtocol.TBinaryProtocolAccelerated and self.thrift_spec is not None and fastbinary is not None:
      oprot.trans.write(fastbinary.encode_binary(self, (self.__class__, self.thrift_spec)))
      return
    oprot.writeStructBegin('URL')
    if self.startOffset is not None:
      oprot.writeFieldBegin('startOffset', TType.I32, 1)
      oprot.writeI32(self.startOffset)
      oprot.writeFieldEnd()
    if self.endOffset is not None:
      oprot.writeFieldBegin('endOffset', TType.I32, 2)
      oprot.writeI32(self.endOffset)
      oprot.writeFieldEnd()
    if self.expandedUrl is not None:
      oprot.writeFieldBegin('expandedUrl', TType.STRING, 3)
      oprot.writeString(self.expandedUrl.encode('utf-8'))
      oprot.writeFieldEnd()
    if self.url is not None:
      oprot.writeFieldBegin('url', TType.STRING, 4)
      oprot.writeString(self.url.encode('utf-8'))
      oprot.writeFieldEnd()
    if self.displayUrl is not None:
      oprot.writeFieldBegin('displayUrl', TType.STRING, 5)
      oprot.writeString(self.displayUrl.encode('utf-8'))
      oprot.writeFieldEnd()
    oprot.writeFieldStop()
    oprot.writeStructEnd()

  def validate(self):
    return


  def __repr__(self):
    L = ['%s=%r' % (key, value)
      for key, value in self.__dict__.iteritems()]
    return '%s(%s)' % (self.__class__.__name__, ', '.join(L))

  def __eq__(self, other):
    return isinstance(other, self.__class__) and self.__dict__ == other.__dict__

  def __ne__(self, other):
    return not (self == other)

class HashTag(object):
  """
  Attributes:
   - text
   - startOffset
   - endOffset
  """

  thrift_spec = (
    None, # 0
    (1, TType.STRING, 'text', None, None, ), # 1
    (2, TType.I32, 'startOffset', None, None, ), # 2
    (3, TType.I32, 'endOffset', None, None, ), # 3
  )

  def __init__(self, text=None, startOffset=None, endOffset=None,):
    self.text = text
    self.startOffset = startOffset
    self.endOffset = endOffset

  def read(self, iprot):
    if iprot.__class__ == TBinaryProtocol.TBinaryProtocolAccelerated and isinstance(iprot.trans, TTransport.CReadableTransport) and self.thrift_spec is not None and fastbinary is not None:
      fastbinary.decode_binary(self, iprot.trans, (self.__class__, self.thrift_spec))
      return
    iprot.readStructBegin()
    while True:
      (fname, ftype, fid) = iprot.readFieldBegin()
      if ftype == TType.STOP:
        break
      if fid == 1:
        if ftype == TType.STRING:
          self.text = iprot.readString().decode('utf-8')
        else:
          iprot.skip(ftype)
      elif fid == 2:
        if ftype == TType.I32:
          self.startOffset = iprot.readI32();
        else:
          iprot.skip(ftype)
      elif fid == 3:
        if ftype == TType.I32:
          self.endOffset = iprot.readI32();
        else:
          iprot.skip(ftype)
      else:
        iprot.skip(ftype)
      iprot.readFieldEnd()
    iprot.readStructEnd()

  def write(self, oprot):
    if oprot.__class__ == TBinaryProtocol.TBinaryProtocolAccelerated and self.thrift_spec is not None and fastbinary is not None:
      oprot.trans.write(fastbinary.encode_binary(self, (self.__class__, self.thrift_spec)))
      return
    oprot.writeStructBegin('HashTag')
    if self.text is not None:
      oprot.writeFieldBegin('text', TType.STRING, 1)
      oprot.writeString(self.text.encode('utf-8'))
      oprot.writeFieldEnd()
    if self.startOffset is not None:
      oprot.writeFieldBegin('startOffset', TType.I32, 2)
      oprot.writeI32(self.startOffset)
      oprot.writeFieldEnd()
    if self.endOffset is not None:
      oprot.writeFieldBegin('endOffset', TType.I32, 3)
      oprot.writeI32(self.endOffset)
      oprot.writeFieldEnd()
    oprot.writeFieldStop()
    oprot.writeStructEnd()

  def validate(self):
    return


  def __repr__(self):
    L = ['%s=%r' % (key, value)
      for key, value in self.__dict__.iteritems()]
    return '%s(%s)' % (self.__class__.__name__, ', '.join(L))

  def __eq__(self, other):
    return isinstance(other, self.__class__) and self.__dict__ == other.__dict__

  def __ne__(self, other):
    return not (self == other)

class TwitterEntities(object):
  """
  Attributes:
   - hashtags
   - urls
   - userMentions
  """

  thrift_spec = (
    None, # 0
    (1, TType.LIST, 'hashtags', (TType.STRUCT,(HashTag, HashTag.thrift_spec)), None, ), # 1
    (2, TType.LIST, 'urls', (TType.STRUCT,(URL, URL.thrift_spec)), None, ), # 2
    (3, TType.LIST, 'userMentions', (TType.STRUCT,(UserMention, UserMention.thrift_spec)), None, ), # 3
  )

  def __init__(self, hashtags=None, urls=None, userMentions=None,):
    self.hashtags = hashtags
    self.urls = urls
    self.userMentions = userMentions

  def read(self, iprot):
    if iprot.__class__ == TBinaryProtocol.TBinaryProtocolAccelerated and isinstance(iprot.trans, TTransport.CReadableTransport) and self.thrift_spec is not None and fastbinary is not None:
      fastbinary.decode_binary(self, iprot.trans, (self.__class__, self.thrift_spec))
      return
    iprot.readStructBegin()
    while True:
      (fname, ftype, fid) = iprot.readFieldBegin()
      if ftype == TType.STOP:
        break
      if fid == 1:
        if ftype == TType.LIST:
          self.hashtags = []
          (_etype10, _size7) = iprot.readListBegin()
          for _i11 in xrange(_size7):
            _elem12 = HashTag()
            _elem12.read(iprot)
            self.hashtags.append(_elem12)
          iprot.readListEnd()
        else:
          iprot.skip(ftype)
      elif fid == 2:
        if ftype == TType.LIST:
          self.urls = []
          (_etype16, _size13) = iprot.readListBegin()
          for _i17 in xrange(_size13):
            _elem18 = URL()
            _elem18.read(iprot)
            self.urls.append(_elem18)
          iprot.readListEnd()
        else:
          iprot.skip(ftype)
      elif fid == 3:
        if ftype == TType.LIST:
          self.userMentions = []
          (_etype22, _size19) = iprot.readListBegin()
          for _i23 in xrange(_size19):
            _elem24 = UserMention()
            _elem24.read(iprot)
            self.userMentions.append(_elem24)
          iprot.readListEnd()
        else:
          iprot.skip(ftype)
      else:
        iprot.skip(ftype)
      iprot.readFieldEnd()
    iprot.readStructEnd()

  def write(self, oprot):
    if oprot.__class__ == TBinaryProtocol.TBinaryProtocolAccelerated and self.thrift_spec is not None and fastbinary is not None:
      oprot.trans.write(fastbinary.encode_binary(self, (self.__class__, self.thrift_spec)))
      return
    oprot.writeStructBegin('TwitterEntities')
    if self.hashtags is not None:
      oprot.writeFieldBegin('hashtags', TType.LIST, 1)
      oprot.writeListBegin(TType.STRUCT, len(self.hashtags))
      for iter25 in self.hashtags:
        iter25.write(oprot)
      oprot.writeListEnd()
      oprot.writeFieldEnd()
    if self.urls is not None:
      oprot.writeFieldBegin('urls', TType.LIST, 2)
      oprot.writeListBegin(TType.STRUCT, len(self.urls))
      for iter26 in self.urls:
        iter26.write(oprot)
      oprot.writeListEnd()
      oprot.writeFieldEnd()
    if self.userMentions is not None:
      oprot.writeFieldBegin('userMentions', TType.LIST, 3)
      oprot.writeListBegin(TType.STRUCT, len(self.userMentions))
      for iter27 in self.userMentions:
        iter27.write(oprot)
      oprot.writeListEnd()
      oprot.writeFieldEnd()
    oprot.writeFieldStop()
    oprot.writeStructEnd()

  def validate(self):
    return


  def __repr__(self):
    L = ['%s=%r' % (key, value)
      for key, value in self.__dict__.iteritems()]
    return '%s(%s)' % (self.__class__.__name__, ', '.join(L))

  def __eq__(self, other):
    return isinstance(other, self.__class__) and self.__dict__ == other.__dict__

  def __ne__(self, other):
    return not (self == other)

class TwitterPlace(object):
  """
  Attributes:
   - placeType
   - countryCode
   - country
   - fullName
   - name
   - id
   - url
   - boundingBox
   - attributes
  """

  thrift_spec = (
    None, # 0
    (1, TType.STRING, 'placeType', None, None, ), # 1
    (2, TType.STRING, 'countryCode', None, None, ), # 2
    (3, TType.STRING, 'country', None, None, ), # 3
    (4, TType.STRING, 'fullName', None, None, ), # 4
    (5, TType.STRING, 'name', None, None, ), # 5
    (6, TType.STRING, 'id', None, None, ), # 6
    (7, TType.STRING, 'url', None, None, ), # 7
    (8, TType.STRUCT, 'boundingBox', (BoundingBox, BoundingBox.thrift_spec), None, ), # 8
    (9, TType.STRUCT, 'attributes', (PlaceAttributes, PlaceAttributes.thrift_spec), None, ), # 9
  )

  def __init__(self, placeType=None, countryCode=None, country=None, fullName=None, name=None, id=None, url=None, boundingBox=None, attributes=None,):
    self.placeType = placeType
    self.countryCode = countryCode
    self.country = country
    self.fullName = fullName
    self.name = name
    self.id = id
    self.url = url
    self.boundingBox = boundingBox
    self.attributes = attributes

  def read(self, iprot):
    if iprot.__class__ == TBinaryProtocol.TBinaryProtocolAccelerated and isinstance(iprot.trans, TTransport.CReadableTransport) and self.thrift_spec is not None and fastbinary is not None:
      fastbinary.decode_binary(self, iprot.trans, (self.__class__, self.thrift_spec))
      return
    iprot.readStructBegin()
    while True:
      (fname, ftype, fid) = iprot.readFieldBegin()
      if ftype == TType.STOP:
        break
      if fid == 1:
        if ftype == TType.STRING:
          self.placeType = iprot.readString().decode('utf-8')
        else:
          iprot.skip(ftype)
      elif fid == 2:
        if ftype == TType.STRING:
          self.countryCode = iprot.readString().decode('utf-8')
        else:
          iprot.skip(ftype)
      elif fid == 3:
        if ftype == TType.STRING:
          self.country = iprot.readString().decode('utf-8')
        else:
          iprot.skip(ftype)
      elif fid == 4:
        if ftype == TType.STRING:
          self.fullName = iprot.readString().decode('utf-8')
        else:
          iprot.skip(ftype)
      elif fid == 5:
        if ftype == TType.STRING:
          self.name = iprot.readString().decode('utf-8')
        else:
          iprot.skip(ftype)
      elif fid == 6:
        if ftype == TType.STRING:
          self.id = iprot.readString().decode('utf-8')
        else:
          iprot.skip(ftype)
      elif fid == 7:
        if ftype == TType.STRING:
          self.url = iprot.readString().decode('utf-8')
        else:
          iprot.skip(ftype)
      elif fid == 8:
        if ftype == TType.STRUCT:
          self.boundingBox = BoundingBox()
          self.boundingBox.read(iprot)
        else:
          iprot.skip(ftype)
      elif fid == 9:
        if ftype == TType.STRUCT:
          self.attributes = PlaceAttributes()
          self.attributes.read(iprot)
        else:
          iprot.skip(ftype)
      else:
        iprot.skip(ftype)
      iprot.readFieldEnd()
    iprot.readStructEnd()

  def write(self, oprot):
    if oprot.__class__ == TBinaryProtocol.TBinaryProtocolAccelerated and self.thrift_spec is not None and fastbinary is not None:
      oprot.trans.write(fastbinary.encode_binary(self, (self.__class__, self.thrift_spec)))
      return
    oprot.writeStructBegin('TwitterPlace')
    if self.placeType is not None:
      oprot.writeFieldBegin('placeType', TType.STRING, 1)
      oprot.writeString(self.placeType.encode('utf-8'))
      oprot.writeFieldEnd()
    if self.countryCode is not None:
      oprot.writeFieldBegin('countryCode', TType.STRING, 2)
      oprot.writeString(self.countryCode.encode('utf-8'))
      oprot.writeFieldEnd()
    if self.country is not None:
      oprot.writeFieldBegin('country', TType.STRING, 3)
      oprot.writeString(self.country.encode('utf-8'))
      oprot.writeFieldEnd()
    if self.fullName is not None:
      oprot.writeFieldBegin('fullName', TType.STRING, 4)
      oprot.writeString(self.fullName.encode('utf-8'))
      oprot.writeFieldEnd()
    if self.name is not None:
      oprot.writeFieldBegin('name', TType.STRING, 5)
      oprot.writeString(self.name.encode('utf-8'))
      oprot.writeFieldEnd()
    if self.id is not None:
      oprot.writeFieldBegin('id', TType.STRING, 6)
      oprot.writeString(self.id.encode('utf-8'))
      oprot.writeFieldEnd()
    if self.url is not None:
      oprot.writeFieldBegin('url', TType.STRING, 7)
      oprot.writeString(self.url.encode('utf-8'))
      oprot.writeFieldEnd()
    if self.boundingBox is not None:
      oprot.writeFieldBegin('boundingBox', TType.STRUCT, 8)
      self.boundingBox.write(oprot)
      oprot.writeFieldEnd()
    if self.attributes is not None:
      oprot.writeFieldBegin('attributes', TType.STRUCT, 9)
      self.attributes.write(oprot)
      oprot.writeFieldEnd()
    oprot.writeFieldStop()
    oprot.writeStructEnd()

  def validate(self):
    return


  def __repr__(self):
    L = ['%s=%r' % (key, value)
      for key, value in self.__dict__.iteritems()]
    return '%s(%s)' % (self.__class__.__name__, ', '.join(L))

  def __eq__(self, other):
    return isinstance(other, self.__class__) and self.__dict__ == other.__dict__

  def __ne__(self, other):
    return not (self == other)

class TwitterCoordinates(object):
  """
  Attributes:
   - type
   - coordinates
  """

  thrift_spec = (
    None, # 0
    (1, TType.STRING, 'type', None, None, ), # 1
    (2, TType.STRUCT, 'coordinates', (TwitterLatLong, TwitterLatLong.thrift_spec), None, ), # 2
  )

  def __init__(self, type=None, coordinates=None,):
    self.type = type
    self.coordinates = coordinates

  def read(self, iprot):
    if iprot.__class__ == TBinaryProtocol.TBinaryProtocolAccelerated and isinstance(iprot.trans, TTransport.CReadableTransport) and self.thrift_spec is not None and fastbinary is not None:
      fastbinary.decode_binary(self, iprot.trans, (self.__class__, self.thrift_spec))
      return
    iprot.readStructBegin()
    while True:
      (fname, ftype, fid) = iprot.readFieldBegin()
      if ftype == TType.STOP:
        break
      if fid == 1:
        if ftype == TType.STRING:
          self.type = iprot.readString().decode('utf-8')
        else:
          iprot.skip(ftype)
      elif fid == 2:
        if ftype == TType.STRUCT:
          self.coordinates = TwitterLatLong()
          self.coordinates.read(iprot)
        else:
          iprot.skip(ftype)
      else:
        iprot.skip(ftype)
      iprot.readFieldEnd()
    iprot.readStructEnd()

  def write(self, oprot):
    if oprot.__class__ == TBinaryProtocol.TBinaryProtocolAccelerated and self.thrift_spec is not None and fastbinary is not None:
      oprot.trans.write(fastbinary.encode_binary(self, (self.__class__, self.thrift_spec)))
      return
    oprot.writeStructBegin('TwitterCoordinates')
    if self.type is not None:
      oprot.writeFieldBegin('type', TType.STRING, 1)
      oprot.writeString(self.type.encode('utf-8'))
      oprot.writeFieldEnd()
    if self.coordinates is not None:
      oprot.writeFieldBegin('coordinates', TType.STRUCT, 2)
      self.coordinates.write(oprot)
      oprot.writeFieldEnd()
    oprot.writeFieldStop()
    oprot.writeStructEnd()

  def validate(self):
    return


  def __repr__(self):
    L = ['%s=%r' % (key, value)
      for key, value in self.__dict__.iteritems()]
    return '%s(%s)' % (self.__class__.__name__, ', '.join(L))

  def __eq__(self, other):
    return isinstance(other, self.__class__) and self.__dict__ == other.__dict__

  def __ne__(self, other):
    return not (self == other)

class TweetInfo(object):
  """
  Attributes:
   - id
   - text
   - createdAt
   - user
   - truncated
   - entities
   - source
   - coordinates
   - place
   - favorited
   - retweeted
   - retweetCount
   - inReplyToScreenName
   - inReplyToStatusId
   - inReplyToUserId
  """

  thrift_spec = (
    None, # 0
    (1, TType.I64, 'id', None, None, ), # 1
    None, # 2
    (3, TType.STRING, 'text', None, None, ), # 3
    (4, TType.STRING, 'createdAt', None, None, ), # 4
    (5, TType.STRUCT, 'user', (TwitterUser, TwitterUser.thrift_spec), None, ), # 5
    (6, TType.BOOL, 'truncated', None, None, ), # 6
    (7, TType.STRUCT, 'entities', (TwitterEntities, TwitterEntities.thrift_spec), None, ), # 7
    (8, TType.STRING, 'source', None, None, ), # 8
    (9, TType.STRUCT, 'coordinates', (TwitterCoordinates, TwitterCoordinates.thrift_spec), None, ), # 9
    None, # 10
    (11, TType.STRUCT, 'place', (TwitterPlace, TwitterPlace.thrift_spec), None, ), # 11
    (12, TType.BOOL, 'favorited', None, None, ), # 12
    (13, TType.BOOL, 'retweeted', None, None, ), # 13
    (14, TType.I32, 'retweetCount', None, None, ), # 14
    (15, TType.STRING, 'inReplyToScreenName', None, None, ), # 15
    (16, TType.I64, 'inReplyToStatusId', None, None, ), # 16
    None, # 17
    (18, TType.I64, 'inReplyToUserId', None, None, ), # 18
  )

  def __init__(self, id=None, text=None, createdAt=None, user=None, truncated=None, entities=None, source=None, coordinates=None, place=None, favorited=None, retweeted=None, retweetCount=None, inReplyToScreenName=None, inReplyToStatusId=None, inReplyToUserId=None,):
    self.id = id
    self.text = text
    self.createdAt = createdAt
    self.user = user
    self.truncated = truncated
    self.entities = entities
    self.source = source
    self.coordinates = coordinates
    self.place = place
    self.favorited = favorited
    self.retweeted = retweeted
    self.retweetCount = retweetCount
    self.inReplyToScreenName = inReplyToScreenName
    self.inReplyToStatusId = inReplyToStatusId
    self.inReplyToUserId = inReplyToUserId

  def read(self, iprot):
    if iprot.__class__ == TBinaryProtocol.TBinaryProtocolAccelerated and isinstance(iprot.trans, TTransport.CReadableTransport) and self.thrift_spec is not None and fastbinary is not None:
      fastbinary.decode_binary(self, iprot.trans, (self.__class__, self.thrift_spec))
      return
    iprot.readStructBegin()
    while True:
      (fname, ftype, fid) = iprot.readFieldBegin()
      if ftype == TType.STOP:
        break
      if fid == 1:
        if ftype == TType.I64:
          self.id = iprot.readI64();
        else:
          iprot.skip(ftype)
      elif fid == 3:
        if ftype == TType.STRING:
          self.text = iprot.readString().decode('utf-8')
        else:
          iprot.skip(ftype)
      elif fid == 4:
        if ftype == TType.STRING:
          self.createdAt = iprot.readString().decode('utf-8')
        else:
          iprot.skip(ftype)
      elif fid == 5:
        if ftype == TType.STRUCT:
          self.user = TwitterUser()
          self.user.read(iprot)
        else:
          iprot.skip(ftype)
      elif fid == 6:
        if ftype == TType.BOOL:
          self.truncated = iprot.readBool();
        else:
          iprot.skip(ftype)
      elif fid == 7:
        if ftype == TType.STRUCT:
          self.entities = TwitterEntities()
          self.entities.read(iprot)
        else:
          iprot.skip(ftype)
      elif fid == 8:
        if ftype == TType.STRING:
          self.source = iprot.readString().decode('utf-8')
        else:
          iprot.skip(ftype)
      elif fid == 9:
        if ftype == TType.STRUCT:
          self.coordinates = TwitterCoordinates()
          self.coordinates.read(iprot)
        else:
          iprot.skip(ftype)
      elif fid == 11:
        if ftype == TType.STRUCT:
          self.place = TwitterPlace()
          self.place.read(iprot)
        else:
          iprot.skip(ftype)
      elif fid == 12:
        if ftype == TType.BOOL:
          self.favorited = iprot.readBool();
        else:
          iprot.skip(ftype)
      elif fid == 13:
        if ftype == TType.BOOL:
          self.retweeted = iprot.readBool();
        else:
          iprot.skip(ftype)
      elif fid == 14:
        if ftype == TType.I32:
          self.retweetCount = iprot.readI32();
        else:
          iprot.skip(ftype)
      elif fid == 15:
        if ftype == TType.STRING:
          self.inReplyToScreenName = iprot.readString().decode('utf-8')
        else:
          iprot.skip(ftype)
      elif fid == 16:
        if ftype == TType.I64:
          self.inReplyToStatusId = iprot.readI64();
        else:
          iprot.skip(ftype)
      elif fid == 18:
        if ftype == TType.I64:
          self.inReplyToUserId = iprot.readI64();
        else:
          iprot.skip(ftype)
      else:
        iprot.skip(ftype)
      iprot.readFieldEnd()
    iprot.readStructEnd()

  def write(self, oprot):
    if oprot.__class__ == TBinaryProtocol.TBinaryProtocolAccelerated and self.thrift_spec is not None and fastbinary is not None:
      oprot.trans.write(fastbinary.encode_binary(self, (self.__class__, self.thrift_spec)))
      return
    oprot.writeStructBegin('TweetInfo')
    if self.id is not None:
      oprot.writeFieldBegin('id', TType.I64, 1)
      oprot.writeI64(self.id)
      oprot.writeFieldEnd()
    if self.text is not None:
      oprot.writeFieldBegin('text', TType.STRING, 3)
      oprot.writeString(self.text.encode('utf-8'))
      oprot.writeFieldEnd()
    if self.createdAt is not None:
      oprot.writeFieldBegin('createdAt', TType.STRING, 4)
      oprot.writeString(self.createdAt.encode('utf-8'))
      oprot.writeFieldEnd()
    if self.user is not None:
      oprot.writeFieldBegin('user', TType.STRUCT, 5)
      self.user.write(oprot)
      oprot.writeFieldEnd()
    if self.truncated is not None:
      oprot.writeFieldBegin('truncated', TType.BOOL, 6)
      oprot.writeBool(self.truncated)
      oprot.writeFieldEnd()
    if self.entities is not None:
      oprot.writeFieldBegin('entities', TType.STRUCT, 7)
      self.entities.write(oprot)
      oprot.writeFieldEnd()
    if self.source is not None:
      oprot.writeFieldBegin('source', TType.STRING, 8)
      oprot.writeString(self.source.encode('utf-8'))
      oprot.writeFieldEnd()
    if self.coordinates is not None:
      oprot.writeFieldBegin('coordinates', TType.STRUCT, 9)
      self.coordinates.write(oprot)
      oprot.writeFieldEnd()
    if self.place is not None:
      oprot.writeFieldBegin('place', TType.STRUCT, 11)
      self.place.write(oprot)
      oprot.writeFieldEnd()
    if self.favorited is not None:
      oprot.writeFieldBegin('favorited', TType.BOOL, 12)
      oprot.writeBool(self.favorited)
      oprot.writeFieldEnd()
    if self.retweeted is not None:
      oprot.writeFieldBegin('retweeted', TType.BOOL, 13)
      oprot.writeBool(self.retweeted)
      oprot.writeFieldEnd()
    if self.retweetCount is not None:
      oprot.writeFieldBegin('retweetCount', TType.I32, 14)
      oprot.writeI32(self.retweetCount)
      oprot.writeFieldEnd()
    if self.inReplyToScreenName is not None:
      oprot.writeFieldBegin('inReplyToScreenName', TType.STRING, 15)
      oprot.writeString(self.inReplyToScreenName.encode('utf-8'))
      oprot.writeFieldEnd()
    if self.inReplyToStatusId is not None:
      oprot.writeFieldBegin('inReplyToStatusId', TType.I64, 16)
      oprot.writeI64(self.inReplyToStatusId)
      oprot.writeFieldEnd()
    if self.inReplyToUserId is not None:
      oprot.writeFieldBegin('inReplyToUserId', TType.I64, 18)
      oprot.writeI64(self.inReplyToUserId)
      oprot.writeFieldEnd()
    oprot.writeFieldStop()
    oprot.writeStructEnd()

  def validate(self):
    return


  def __repr__(self):
    L = ['%s=%r' % (key, value)
      for key, value in self.__dict__.iteritems()]
    return '%s(%s)' % (self.__class__.__name__, ', '.join(L))

  def __eq__(self, other):
    return isinstance(other, self.__class__) and self.__dict__ == other.__dict__

  def __ne__(self, other):
    return not (self == other)



#
# Autogenerated by Thrift Compiler (1.0.0-dev)
#
# DO NOT EDIT UNLESS YOU ARE SURE THAT YOU KNOW WHAT YOU ARE DOING
#
#  options string: py:new_style,utf8strings
#

from thrift.Thrift import TType, TMessageType, TException, TApplicationException

from thrift.transport import TTransport
from thrift.protocol import TBinaryProtocol, TProtocol
try:
  from thrift.protocol import fastbinary
except:
  fastbinary = None



class TextSpan(object):
  """
  A span of text within a single communication, identified by a pair
  of character offsets. In this context, a "character offset" is a
  zero-based count of UTF-16 codepoints. I.e., if you are using
  Java, or are using a Python build where sys.maxunicode==0xffff,
  then the "character offset" is an offset into the standard
  (unicode) string data type. If you are using a Python build where
  sys.maxunicode==0xffffffff, then you would need to encode the
  unicode string using UTF-16 before using the character offsets.

  NOTE: This span represents a best guess, or 'provenance':
  it cannot be guaranteed that this text span matches the _exact_
  text of the original document, but is the annotation's best
  effort at such a representation.

  Attributes:
   - start: Start character, inclusive.
   - ending: End character, exclusive
  """

  thrift_spec = (
    None, # 0
    (1, TType.I32, 'start', None, None, ), # 1
    (2, TType.I32, 'ending', None, None, ), # 2
  )

  def __init__(self, start=None, ending=None,):
    self.start = start
    self.ending = ending

  def read(self, iprot):
    if iprot.__class__ == TBinaryProtocol.TBinaryProtocolAccelerated and isinstance(iprot.trans, TTransport.CReadableTransport) and self.thrift_spec is not None and fastbinary is not None:
      fastbinary.decode_binary(self, iprot.trans, (self.__class__, self.thrift_spec))
      return
    iprot.readStructBegin()
    while True:
      (fname, ftype, fid) = iprot.readFieldBegin()
      if ftype == TType.STOP:
        break
      if fid == 1:
        if ftype == TType.I32:
          self.start = iprot.readI32();
        else:
          iprot.skip(ftype)
      elif fid == 2:
        if ftype == TType.I32:
          self.ending = iprot.readI32();
        else:
          iprot.skip(ftype)
      else:
        iprot.skip(ftype)
      iprot.readFieldEnd()
    iprot.readStructEnd()

  def write(self, oprot):
    if oprot.__class__ == TBinaryProtocol.TBinaryProtocolAccelerated and self.thrift_spec is not None and fastbinary is not None:
      oprot.trans.write(fastbinary.encode_binary(self, (self.__class__, self.thrift_spec)))
      return
    oprot.writeStructBegin('TextSpan')
    if self.start is not None:
      oprot.writeFieldBegin('start', TType.I32, 1)
      oprot.writeI32(self.start)
      oprot.writeFieldEnd()
    if self.ending is not None:
      oprot.writeFieldBegin('ending', TType.I32, 2)
      oprot.writeI32(self.ending)
      oprot.writeFieldEnd()
    oprot.writeFieldStop()
    oprot.writeStructEnd()

  def validate(self):
    if self.start is None:
      raise TProtocol.TProtocolException(message='Required field start is unset!')
    if self.ending is None:
      raise TProtocol.TProtocolException(message='Required field ending is unset!')
    return


  def __repr__(self):
    L = ['%s=%r' % (key, value)
      for key, value in self.__dict__.iteritems()]
    return '%s(%s)' % (self.__class__.__name__, ', '.join(L))

  def __eq__(self, other):
    return isinstance(other, self.__class__) and self.__dict__ == other.__dict__

  def __ne__(self, other):
    return not (self == other)

class AudioSpan(object):
  """
  A span of audio within a single communication, identified by a
  pair of time offests. Time offsets are zero-based.

  NOTE: This span represents a best guess, or 'provenance':
  it cannot be guaranteed that this text span matches the _exact_
  text of the original document, but is the annotation's best
  effort at such a representation.

  Attributes:
   - start: Start time (in seconds)
   - ending: End time (in seconds)
  """

  thrift_spec = (
    None, # 0
    (1, TType.I64, 'start', None, None, ), # 1
    (2, TType.I64, 'ending', None, None, ), # 2
  )

  def __init__(self, start=None, ending=None,):
    self.start = start
    self.ending = ending

  def read(self, iprot):
    if iprot.__class__ == TBinaryProtocol.TBinaryProtocolAccelerated and isinstance(iprot.trans, TTransport.CReadableTransport) and self.thrift_spec is not None and fastbinary is not None:
      fastbinary.decode_binary(self, iprot.trans, (self.__class__, self.thrift_spec))
      return
    iprot.readStructBegin()
    while True:
      (fname, ftype, fid) = iprot.readFieldBegin()
      if ftype == TType.STOP:
        break
      if fid == 1:
        if ftype == TType.I64:
          self.start = iprot.readI64();
        else:
          iprot.skip(ftype)
      elif fid == 2:
        if ftype == TType.I64:
          self.ending = iprot.readI64();
        else:
          iprot.skip(ftype)
      else:
        iprot.skip(ftype)
      iprot.readFieldEnd()
    iprot.readStructEnd()

  def write(self, oprot):
    if oprot.__class__ == TBinaryProtocol.TBinaryProtocolAccelerated and self.thrift_spec is not None and fastbinary is not None:
      oprot.trans.write(fastbinary.encode_binary(self, (self.__class__, self.thrift_spec)))
      return
    oprot.writeStructBegin('AudioSpan')
    if self.start is not None:
      oprot.writeFieldBegin('start', TType.I64, 1)
      oprot.writeI64(self.start)
      oprot.writeFieldEnd()
    if self.ending is not None:
      oprot.writeFieldBegin('ending', TType.I64, 2)
      oprot.writeI64(self.ending)
      oprot.writeFieldEnd()
    oprot.writeFieldStop()
    oprot.writeStructEnd()

  def validate(self):
    if self.start is None:
      raise TProtocol.TProtocolException(message='Required field start is unset!')
    if self.ending is None:
      raise TProtocol.TProtocolException(message='Required field ending is unset!')
    return


  def __repr__(self):
    L = ['%s=%r' % (key, value)
      for key, value in self.__dict__.iteritems()]
    return '%s(%s)' % (self.__class__.__name__, ', '.join(L))

  def __eq__(self, other):
    return isinstance(other, self.__class__) and self.__dict__ == other.__dict__

  def __ne__(self, other):
    return not (self == other)
